@@ -50,7 +50,7 @@
 
 #define E_CAL_BACKEND_KOLAB_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), E_TYPE_CAL_BACKEND_KOLAB, ECalBackendKolabPrivate))
 
-G_DEFINE_TYPE (ECalBackendKolab, e_cal_backend_kolab, E_TYPE_CAL_BACKEND_SYNC);
+G_DEFINE_TYPE (ECalBackendKolab, e_cal_backend_kolab, E_TYPE_CAL_BACKEND_SYNC)
 
 /* private structures for Kolab calendar class ********************************/
 
@@ -525,7 +525,7 @@ e_cal_backend_kolab_get_object (ECalBackendSync *backend,
 		g_object_unref (oldcomp);
 	}
 #endif
-	ecalcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, &error);
+	ecalcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, FALSE, &error);
 	if (error != NULL) {
 		status = kolab_util_calendar_map_error (error);
 		g_warning ("%s()[%u]: %s", __func__, __LINE__, error->message);
@@ -571,7 +571,7 @@ e_cal_backend_kolab_get_object_list (ECalBackendSync *backend,
 	for (it = g_list_first (uid_list); it != NULL; it = g_list_next (it)) {
 		gchar *uid = it->data;
 		ECalComponent *ecalcomp = NULL;
-		ecalcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, &error);
+		ecalcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, TRUE, &error);
 		if (error != NULL) {
 			g_warning ("%s()[%u]: %s", __func__, __LINE__, error->message);
 			g_error_free (error);
@@ -668,7 +668,7 @@ e_cal_backend_kolab_create_object (ECalBackendSync *backend,
 		}
 	}
 
-	if (! kolab_util_calendar_cache_assure_uid_on_ecalcomponent (priv->cal_cache, priv->cal_koma, priv->cal_uri, ecalcomp, &error)) {
+	if (! kolab_util_calendar_cache_assure_uid_on_ecalcomponent (priv->cal_cache, priv->cal_koma, priv->cal_uri, ecalcomp, FALSE, &error)) {
 		status = kolab_util_calendar_map_error (error);
 		g_warning ("%s()[%u]: %s", __func__, __LINE__, error->message);
 		g_error_free (error);
@@ -752,7 +752,7 @@ e_cal_backend_kolab_modify_object (ECalBackendSync *backend,
 		return GNOME_Evolution_Calendar_InvalidObject;
 	e_cal_component_get_uid (ecalcomp, &uid);
 	
-	oldcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, &error);
+	oldcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, FALSE, &error);
 	if (error != NULL) {
 		/* TODO: how to handle request to modify non existing objects? */
 		g_warning ("%s()[%u]: %s", __func__, __LINE__, error->message);
@@ -783,7 +783,7 @@ e_cal_backend_kolab_modify_object (ECalBackendSync *backend,
 		e_cal_component_set_recurid (ecalcomp, NULL);
 		/* This removes ecalcomp from the recurrence. */
 		newcomp = kolab_util_calendar_cache_remove_instance (priv->cal_cache, CALOBJ_MOD_THIS, oldcomp, uid, rid);
-		if (! kolab_util_calendar_cache_assure_uid_on_ecalcomponent (priv->cal_cache, priv->cal_koma, priv->cal_uri, ecalcomp, &error)) {
+		if (! kolab_util_calendar_cache_assure_uid_on_ecalcomponent (priv->cal_cache, priv->cal_koma, priv->cal_uri, ecalcomp, TRUE, &error)) {
 			status = kolab_util_calendar_map_error (error);
 			g_warning ("%s()[%u]: %s", __func__, __LINE__, error->message);
 			g_error_free (error);
@@ -891,7 +891,7 @@ e_cal_backend_kolab_remove_object (ECalBackendSync *backend,
 	if (rid == NULL)
 		mod = CALOBJ_MOD_ALL;
 
-	oldcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, &error);
+	oldcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, FALSE, &error);
 	if (error != NULL) {
 		switch (error->code) {
 		case KOLAB_BACKEND_ERROR_NOTFOUND:
@@ -1205,10 +1205,11 @@ e_cal_backend_kolab_get_free_busy (ECalBackendSync *backend,
 	GList *it;
 	GError *error = NULL;
 	gboolean internal_state = TRUE;
+	KolabSettingsHandler *ksettings = NULL;
+
 	(void) cal;
 	(void) start;
 	(void) end;
-	KolabSettingsHandler *ksettings = NULL;
 
 	ksettings = kolab_mail_access_get_settings_handler (priv->cal_koma);
 	if (ksettings == NULL)
@@ -1308,7 +1309,7 @@ e_cal_backend_kolab_start_query (ECalBackend *backend,
 	for (it = g_list_first (uid_list); it != NULL; it = g_list_next (it)) {
 		gchar *uid = it->data;
 		ECalComponent *ecalcomp = NULL;
-		ecalcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, &error);
+		ecalcomp = kolab_util_calendar_cache_get_object (priv->cal_cache, priv->cal_koma, priv->cal_uri, uid, TRUE, &error);
 		if (error != NULL) {
 			g_warning ("%s()[%u]: %s", __func__, __LINE__, error->message);
 			g_error_free (error);
