@@ -26,7 +26,7 @@
 
 #include <string.h>
 
-#include <camel/camel.h>
+#include <libekolabutil/camel-system-headers.h>
 
 #include <camel/providers/imapx/camel-imapx-store.h>
 #include <camel/providers/imapx/camel-imapx-server.h>
