@@ -532,8 +532,8 @@ GtkWidget *
 org_gnome_kolab_account_setup (EPlugin *epl, EConfigHookItemFactoryData *data)
 {
 	g_debug ("%s() called.\n", __func__);
-	g_debug (" + epl: %p", epl);
-	g_debug (" + data: %p", data);
+	g_debug (" + epl: %p", (void*)epl);
+	g_debug (" + data: %p", (void*)data);
 
 	/* is NULL on New Account creation, add more stuff here */
 	return NULL;
