@@ -130,7 +130,7 @@ struct _KolabMailInfoDbPrivate
 
 #define KOLAB_MAIL_INFO_DB_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KOLAB_TYPE_MAIL_INFO_DB, KolabMailInfoDbPrivate))
 
-G_DEFINE_TYPE (KolabMailInfoDb, kolab_mail_info_db, G_TYPE_OBJECT);
+G_DEFINE_TYPE (KolabMailInfoDb, kolab_mail_info_db, G_TYPE_OBJECT)
 
 /*----------------------------------------------------------------------------*/
 /* SQLite helpers */
@@ -782,7 +782,7 @@ static void
 kolab_mail_info_db_class_init (KolabMailInfoDbClass *klass)
 {
 	GObjectClass* object_class = G_OBJECT_CLASS (klass);
-	GObjectClass* parent_class = G_OBJECT_CLASS (klass);
+	/* GObjectClass* parent_class = G_OBJECT_CLASS (klass); */
 
 	g_type_class_add_private (klass, sizeof (KolabMailInfoDbPrivate));
 
