@@ -90,7 +90,7 @@ struct _KolabMailSideCachePrivate
 
 #define KOLAB_MAIL_SIDE_CACHE_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KOLAB_TYPE_MAIL_SIDE_CACHE, KolabMailSideCachePrivate))
 
-G_DEFINE_TYPE (KolabMailSideCache, kolab_mail_side_cache, G_TYPE_OBJECT);
+G_DEFINE_TYPE (KolabMailSideCache, kolab_mail_side_cache, G_TYPE_OBJECT)
 
 /*----------------------------------------------------------------------------*/
 /* SQLite helpers */
@@ -498,7 +498,7 @@ static void
 kolab_mail_side_cache_class_init (KolabMailSideCacheClass *klass)
 {
 	GObjectClass* object_class = G_OBJECT_CLASS (klass);
-	GObjectClass* parent_class = G_OBJECT_CLASS (klass);
+	/* GObjectClass* parent_class = G_OBJECT_CLASS (klass); */
 
 	g_type_class_add_private (klass, sizeof (KolabMailSideCachePrivate));
 
