@@ -52,7 +52,7 @@ struct _KolabSettingsHandlerPrivate
 
 #define KOLAB_SETTINGS_HANDLER_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KOLAB_TYPE_SETTINGS_HANDLER, KolabSettingsHandlerPrivate))
 
-G_DEFINE_TYPE (KolabSettingsHandler, kolab_settings_handler, G_TYPE_OBJECT);
+G_DEFINE_TYPE (KolabSettingsHandler, kolab_settings_handler, G_TYPE_OBJECT)
 
 /*----------------------------------------------------------------------------*/
 
@@ -310,7 +310,7 @@ static void
 kolab_settings_handler_class_init (KolabSettingsHandlerClass *klass)
 {
 	GObjectClass* object_class = G_OBJECT_CLASS (klass);
-	GObjectClass* parent_class = G_OBJECT_CLASS (klass);
+	/* GObjectClass* parent_class = G_OBJECT_CLASS (klass); */
 
 	g_type_class_add_private (klass, sizeof (KolabSettingsHandlerPrivate));
 
@@ -771,7 +771,6 @@ kolab_settings_handler_create_table (KolabSettingsHandlerTblID tbl_id)
 
 /**
  * kolab_settings_handler_set_value:
- * kolab_settings_handler_get_bool_field:
  * @self: a #KolabSettingsHandler instance
  * @tbl_id: ID for the internal table to store the @value in
  * @key: the key string to reference the value with
@@ -831,7 +830,6 @@ kolab_settings_handler_set_value (KolabSettingsHandler *self,
 
 /**
  * kolab_settings_handler_get_value:
- * kolab_settings_handler_get_bool_field:
  * @self: a #KolabSettingsHandler instance
  * @tbl_id: ID for the internal table to store the @value in
  * @key: the key string to reference the value with
