@@ -64,10 +64,12 @@ static Icontact_phone_type phone_type_e_to_i(GList *vcard_types);
 I_contact*
 conv_EContact_to_I_contact (const EContact* e_contact, GError** error)
 {
+	I_contact *i_contact = NULL;
+	
 	g_assert(error != NULL && *error == NULL);
 	log_debug ("\nconv_EContact_to_I_contact(): convert EContact to I_contact struct.");
 
-	I_contact *i_contact = new_i_contact ();
+	i_contact = new_i_contact ();
 
 	if (e_contact) {
 		process_contact_e_to_i (i_contact, e_contact);
@@ -95,11 +97,12 @@ is_not_empty(gchar* str)
 static void
 process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 {
-	// Tested:
-	// - Not needed, works also without duplicate.
-	// - There is not more memory needed with duplicate / everything is freed.
-	// - Common->body has 3 different states in carriage returns and newlines without duplicate.
-	// - Maybe there is more delay for copying.
+	/* Tested:
+	 * - Not needed, works also without duplicate.
+	 * - There is not more memory needed with duplicate / everything is freed.
+	 * - Common->body has 3 different states in carriage returns and newlines without duplicate.
+	 * - Maybe there is more delay for copying.
+	 */
 	EContact* e_contact_dup = e_contact_duplicate ( (EContact*) e_contact );
 
 	EContactDate *date;
@@ -110,24 +113,30 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 	gchar *buffer;
 
 	if (e_contact_dup != NULL) {
+		GHashTable *kstore_hash = NULL;
+		gchar *nick_name = NULL;
+		gchar *full_name = NULL;
+		EVCardAttribute *attribute = NULL;
+		gchar *value = NULL;
+		
 		log_debug("read kolab store information");
 
-		GHashTable *kstore_hash = kolab_store_read_values (e_contact_dup, i_contact);
+		kstore_hash = kolab_store_read_values (e_contact_dup, i_contact);
 
 		log_debug("process birth date");
-		//e_contact_get              (EContact *contact, EContactField field_id);
-		//*****************************************************************SET BIRTHDAY******************************************
+		/* e_contact_get              (EContact *contact, EContactField field_id); */
+		/* *****************************************************************SET BIRTHDAY****************************************** */
 		date = e_contact_get (e_contact_dup, E_CONTACT_BIRTH_DATE);
 		if (date)
 			i_contact->birthday = g_date_new_dmy ((GDateDay)date->day, (GDateMonth)date->month, (GDateYear)date->year);
 		e_contact_date_free(date);
-		//*****************************************************************SET ANNIVERSARY***************************************
+		/* *****************************************************************SET ANNIVERSARY*************************************** */
 		log_debug("process anniversary");
 		date = e_contact_get (e_contact_dup, E_CONTACT_ANNIVERSARY);
 		if (date)
 			i_contact->anniversary = g_date_new_dmy ((GDateDay)date->day, (GDateMonth)date->month, (GDateYear)date->year);
 		e_contact_date_free(date);
-		//*****************************************************************SET ADDRESSES*****************************************
+		/* *****************************************************************SET ADDRESSES***************************************** */
 		log_debug("process addresses");
 		address = e_contact_get (e_contact_dup, E_CONTACT_ADDRESS_HOME);
 		if (address)
@@ -141,7 +150,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 		if (address)
 			add_address (e_contact_dup, address, i_contact,	E_CONTACT_ADDRESS_OTHER, kstore_hash);
 		e_contact_address_free(address);
-		//*****************************************************************GEO **************************************************
+		/* *****************************************************************GEO ************************************************** */
 		log_debug("process GEO");
 		geo = e_contact_get (e_contact_dup, E_CONTACT_GEO);
 		if (geo) {
@@ -152,7 +161,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 			}
 		}
 		e_contact_geo_free(geo);
-		//*****************************************************************SET NAME**********************************************
+		/* *****************************************************************SET NAME********************************************** */
 		log_debug("process names");
 		name = e_contact_get (e_contact_dup, E_CONTACT_NAME);
 		if (is_not_empty(name->suffixes))
@@ -170,17 +179,17 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 
 		e_contact_name_free(name);
 
-		gchar *nick_name = e_contact_get (e_contact_dup, E_CONTACT_NICKNAME);
+		nick_name = e_contact_get (e_contact_dup, E_CONTACT_NICKNAME);
 		if (is_not_empty(nick_name))
 			i_contact->nick_name = g_string_new (nick_name);
 		g_free(nick_name);
 
-		gchar *full_name = e_contact_get (e_contact_dup, E_CONTACT_FULL_NAME);
+		full_name = e_contact_get (e_contact_dup, E_CONTACT_FULL_NAME);
 		if (is_not_empty(full_name))
 			i_contact->full_name = g_string_new (full_name);
 		g_free(full_name);
 
-		//*****************************************************************SET EMAIL**************************************
+		/* *****************************************************************SET EMAIL************************************** */
 		log_debug("process emails");
 		buffer = e_contact_get (e_contact_dup, E_CONTACT_EMAIL_1);
 		if (buffer)
@@ -199,7 +208,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 			add_email (e_contact_dup, E_CONTACT_EMAIL_4, i_contact, buffer, kstore_hash);
 		g_free(buffer);
 
-		//*****************************************************************SET PHONE**************************************
+		/* *****************************************************************SET PHONE************************************** */
 		log_debug("process phones");
 
 		/*
@@ -212,7 +221,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 		add_phone_numbers(e_contact_dup, i_contact, kstore_hash);
 
 
-		//*****************************************************************SET ORGANIZATIONAL FIELDS**********************
+		/* *****************************************************************SET ORGANIZATIONAL FIELDS********************** */
 
 		log_debug("process organization fields");
 
@@ -240,7 +249,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 		if (is_not_empty(buffer))
 			i_contact->assistant = g_string_new (buffer);
 		g_free(buffer);
-		//*****************************************************************SET WEB FIELDS*********************************
+		/* *****************************************************************SET WEB FIELDS********************************* */
 		log_debug("process web page");
 		buffer = e_contact_get (e_contact_dup, E_CONTACT_HOMEPAGE_URL);
 		if (is_not_empty(buffer))
@@ -251,13 +260,13 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 		if (is_not_empty(buffer))
 			i_contact->free_busy_url = g_string_new (buffer);
 		g_free(buffer);
-		//*****************************************************************SET CATEGORY***********************************
+		/* *****************************************************************SET CATEGORY*********************************** */
 		log_debug("process categories");
 		buffer = e_contact_get (e_contact_dup, E_CONTACT_CATEGORIES);
 		if (buffer)
 			i_contact->common->categories = g_string_new (buffer);
 		g_free(buffer);
-		//*****************************************************************SET MISC FIELDS********************************
+		/* *****************************************************************SET MISC FIELDS******************************** */
 
 		log_debug("process misc fields");
 
@@ -270,7 +279,7 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 			i_contact->office_location = g_string_new (buffer);
 		g_free(buffer);
 
-		//*****************************************************************SET COMMON FIELDS******************************
+		/* *****************************************************************SET COMMON FIELDS****************************** */
 		buffer = e_contact_get (e_contact_dup, E_CONTACT_UID);
 		if (buffer)
 			i_contact->common->uid = g_string_new (buffer);
@@ -281,12 +290,15 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 		g_free(buffer);
 		buffer = e_contact_get (e_contact_dup, E_CONTACT_REV);
 		if (buffer) {
-			if (buffer[10] == 'T') // get rid of 'T' in iso time stamp if neccessary
+			struct tm *t = NULL;
+			time_t *tt = NULL;
+			
+			if (buffer[10] == 'T') /* get rid of 'T' in iso time stamp if neccessary */
 			        buffer[10] = ' ';
 
-			struct tm *t = g_new0(struct tm, 1);
+			t = g_new0(struct tm, 1);
 			strptime(buffer, "%Y-%m-%d %H:%M:%S", t);
-			time_t *tt = g_new0(time_t, 1);
+			tt = g_new0(time_t, 1);
 			*tt = time_gm(t);
 			g_free(t);
 			i_contact->common->last_modified_datetime = g_new0(Date_or_datetime, 1);
@@ -298,18 +310,20 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 			*i_contact->common->last_modified_datetime->date_time = time(0);
 		}
 		buffer = NULL;
-		EVCardAttribute *attribute = e_vcard_get_attribute((EVCard *) e_contact_dup, ICONTACT_KOLAB_CREATED);
-		gchar *value = NULL;
+		attribute = e_vcard_get_attribute((EVCard *) e_contact_dup, ICONTACT_KOLAB_CREATED);
 		if(attribute)
 			value = e_vcard_attribute_get_value (attribute);
 
 		if (attribute && value) {
-			if (value[10] == 'T') // get rid of 'T' in iso time stamp if neccessary
+			struct tm *t2 = NULL;
+			time_t *tt2 = NULL;
+			
+			if (value[10] == 'T') /* get rid of 'T' in iso time stamp if neccessary */
 				value[10] = ' ';
 
-			struct tm *t2 = g_new0(struct tm, 1);
+			t2 = g_new0(struct tm, 1);
 			strptime (value, "%Y-%m-%d %H:%M:%S", t2);
-			time_t *tt2 = g_new0(time_t, 1);
+			tt2 = g_new0(time_t, 1);
 			*tt2 = time_gm (t2);
 			g_free(t2);
 			i_contact->common->creation_datetime = new_date_or_datetime();
@@ -320,30 +334,32 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 			*i_contact->common->creation_datetime->date_time = *i_contact->common->last_modified_datetime->date_time;
 		}
 
-//		g_debug("populateIContactFromEContact: icontact->common->uid == '%s'", icontact->common->uid->str);
+		/* g_debug("populateIContactFromEContact: icontact->common->uid == '%s'", icontact->common->uid->str); */
 
-		//*****************************************************************SET PICTURE FIELDS*****************************
+		/* *****************************************************************SET PICTURE FIELDS***************************** */
 
 		log_debug("process picture fields");
 
 		e_contact_photo = e_contact_get (e_contact_dup, E_CONTACT_PHOTO);
 
 		if (e_contact_photo && e_contact_photo->type == E_CONTACT_PHOTO_TYPE_INLINED) {
-			//Bin_attachment *photo;
-			//photo = (Bin_attachment *) malloc ( sizeof(Bin_attachment) );
+			gchar *d = NULL;
+			
+			/* Bin_attachment *photo; */
+			/* photo = (Bin_attachment *) malloc ( sizeof(Bin_attachment) ); */
 			i_contact->photo = g_new0(Kolab_conv_mail_part, 1);
 
 			i_contact->photo->length = e_contact_photo->data.inlined.length;
 			i_contact->photo->data = g_new0(gchar, i_contact->photo->length);
 
-			// handle mime type
-			gchar *d = (gchar*) e_contact_photo->data.inlined.data;
+			/* handle mime type */
+			d = (gchar*) e_contact_photo->data.inlined.data;
 
-			// JPEG SOI marker (first two bytes): FF D8
+			/* JPEG SOI marker (first two bytes): FF D8 */
 			if (memcmp (d, "\xFF\xD8", 2) == 0) {
 				i_contact->photo->name = g_strdup("kolab-picture.jpg");
 				i_contact->photo->mime_type = g_strdup("image/jpeg");
-			// PNG signature (first eight bytes): 89 50 4E 47 0D 0A 1A 0A
+			/* PNG signature (first eight bytes): 89 50 4E 47 0D 0A 1A 0A */
 			} else if (memcmp (d, "\x89PNG\r\n\x1A\n", 8) == 0) {
 				i_contact->photo->name = g_strdup("kolab-picture.png");
 				i_contact->photo->mime_type = g_strdup("image/png");
@@ -358,23 +374,23 @@ process_contact_e_to_i (I_contact* i_contact, const EContact *e_contact)
 		e_contact_photo_free(e_contact_photo);
 
 
-		//*************************************SET X-CUSTOM FIELDS (ALL IM fields, BlogFeed URL and self defined fields)***
+		/* *************************************SET X-CUSTOM FIELDS (ALL IM fields, BlogFeed URL and self defined fields)*** */
 
 		log_debug("process X-CUSTOMER fields");
 
 		add_custom_fields(e_contact_dup, i_contact, kstore_hash);
 
-		//*************************************SET EVOLUTION HIDDEN FIELDS BACK IN ICONTACT (In KolabStore) **************
+		/* *************************************SET EVOLUTION HIDDEN FIELDS BACK IN ICONTACT (In KolabStore) ************** */
 
 
 		kolab_store_handle_attachments(e_contact_dup, i_contact->common);
 
-		//*************************************SET EVOLUTION SPECIFIC FIELDS INTO EVOLUTIONSTORE IN ICONTACT *************
+		/* *************************************SET EVOLUTION SPECIFIC FIELDS INTO EVOLUTIONSTORE IN ICONTACT ************* */
 
 		i_evo_store_add_contact(e_contact_dup, i_contact->common);
 
-		//TODO: COMPLETE ALL REMAINING FIELDS
-		//KLBC_CNT_KEY
+		/* TODO: COMPLETE ALL REMAINING FIELDS */
+		/* KLBC_CNT_KEY */
 		g_hash_table_unref(kstore_hash);
 
 	} else
@@ -393,7 +409,7 @@ add_address (const EContact *e_contact, EContactAddress *e_address, I_contact* i
 	Address *addr = new_address ();
 
 	addr->type = address_type_e_to_i(e_addr_type);
-//	g_debug ("**** e_address_type: %d, addr->type: %d ****", e_addr_type, addr->type);
+	/* g_debug ("**** e_address_type: %d, addr->type: %d ****", e_addr_type, addr->type); */
 
 	if (e_address->street)
 		addr->street = g_string_new (e_address->street);
@@ -435,19 +451,21 @@ add_email (const EContact *e_contact, EContactField e_field,
 static void
 add_phone_numbers (const EContact *e_contact, I_contact* i_contact, GHashTable *k_store_hash)
 {
-	// read phone tags from vcard manually
+	/* read phone tags from vcard manually */
 	GList *attrs;
 	GList *attr;
 	attrs = e_vcard_get_attributes (E_VCARD (e_contact));
 
-	// for all attributes in vcard object
+	/* for all attributes in vcard object */
 	for (attr = attrs; attr;)
 	{
 		EVCardAttribute *a = attr->data;
 
-		// do if it is a phone object
+		/* do if it is a phone object */
 		if (!strcmp (EVC_TEL, e_vcard_attribute_get_name (a)))
 		{
+			gchar* value = NULL;
+			
 			GList *params = e_vcard_attribute_get_param (a, EVC_TYPE);
 			GList *param;
 			GList *type_list = NULL;
@@ -457,8 +475,8 @@ add_phone_numbers (const EContact *e_contact, I_contact* i_contact, GHashTable *
 				type_list = g_list_append(type_list, p);
 			}
 
-			// phone number
-			gchar* value = e_vcard_attribute_get_value(a);
+			/* phone number */
+			value = e_vcard_attribute_get_value(a);
 
 			if (value != NULL) {
 				Phone_number *phone_nr = g_new0(Phone_number, 1);
@@ -480,12 +498,14 @@ add_phone_numbers (const EContact *e_contact, I_contact* i_contact, GHashTable *
 						EVCardAttributeParam *eparam = paramlist->data;
 
 						if (eparam != NULL) {
+							GList* xml_str_list = NULL;
+							
 							gchar *id_str = (gchar*)eparam;
 							gint id = strtol(id_str, (gchar**)0, 10);
 							gint *id_ptr = g_new0(gint, 1);
 							log_debug("found kolab store id %d", id);
 							*id_ptr = id;
-							GList* xml_str_list = g_hash_table_lookup(k_store_hash, id_ptr);
+							xml_str_list = g_hash_table_lookup(k_store_hash, id_ptr);
 							g_free(id_ptr);
 							xml_str_list = g_list_last(xml_str_list);
 							for (;xml_str_list != NULL; xml_str_list = xml_str_list->prev) {
@@ -502,7 +522,7 @@ add_phone_numbers (const EContact *e_contact, I_contact* i_contact, GHashTable *
 			g_list_free(type_list);
 			type_list = NULL;
 		}
-		// next attribute in vcard
+		/* next attribute in vcard */
 		attr = attr->next;
 	}
 }
@@ -513,44 +533,44 @@ add_phone_numbers (const EContact *e_contact, I_contact* i_contact, GHashTable *
 static void
 add_custom_fields (const EContact *e_contact, I_contact* i_contact, GHashTable *k_store_hash)
 {
-	// read phone tags from vcard manually
+	/* read phone tags from vcard manually */
 	GList *attrs;
 	GList *attr;
 	attrs = e_vcard_get_attributes (E_VCARD (e_contact));
 
-	// for all attributes in vcard object
+	/* for all attributes in vcard object */
 	for (attr = attrs; attr;) {
 		EVCardAttribute *a = attr->data;
 
 		Custom *custom_field = g_new0(Custom, 1);
 
-		// do if it is a blog object
-		if (!strcmp (EVC_X_BLOG_URL, e_vcard_attribute_get_name(a))) {	// blogfeed
+		/* do if it is a blog object */
+		if (!strcmp (EVC_X_BLOG_URL, e_vcard_attribute_get_name(a))) {	/* blogfeed */
 			custom_field->name = g_string_new(KLBX_CNT_X_CUSTOM_NAME_BLOGFEED);
 			custom_field->app = g_string_new("");
 		}
 		else {
 			custom_field->name = g_string_new("All");
 
-			if (!strcmp (EVC_X_AIM, e_vcard_attribute_get_name (a))) 			// im aim
+			if (!strcmp (EVC_X_AIM, e_vcard_attribute_get_name (a))) 		/* im aim */
 				custom_field->app = g_string_new(KLBX_CNT_X_CUSTOM_APP_AIM);
-			else if (!strcmp (EVC_X_JABBER, e_vcard_attribute_get_name (a))) 	// im jabber/xmpp
+			else if (!strcmp (EVC_X_JABBER, e_vcard_attribute_get_name (a))) 	/* im jabber/xmpp */
 				custom_field->app = g_string_new(KLBX_CNT_X_CUSTOM_APP_XMPP);
-			else if (!strcmp (EVC_X_YAHOO, e_vcard_attribute_get_name (a))) 	// im yahoo
+			else if (!strcmp (EVC_X_YAHOO, e_vcard_attribute_get_name (a))) 	/* im yahoo */
 				custom_field->app = g_string_new(KLBX_CNT_X_CUSTOM_APP_YAHOO);
-			else if (!strcmp (EVC_X_GADUGADU, e_vcard_attribute_get_name (a))) 	// im gadu-gadu
+			else if (!strcmp (EVC_X_GADUGADU, e_vcard_attribute_get_name (a))) 	/* im gadu-gadu */
 				custom_field->app = g_string_new(KLBX_CNT_X_CUSTOM_APP_GADUGADU);
-			else if (!strcmp (EVC_X_MSN, e_vcard_attribute_get_name (a))) 		// im msn
+			else if (!strcmp (EVC_X_MSN, e_vcard_attribute_get_name (a))) 		/* im msn */
 				custom_field->app = g_string_new(KLBX_CNT_X_CUSTOM_APP_MSN);
-			else if (!strcmp (EVC_X_ICQ, e_vcard_attribute_get_name (a))) 		// im icq
+			else if (!strcmp (EVC_X_ICQ, e_vcard_attribute_get_name (a))) 		/* im icq */
 				custom_field->app = g_string_new(KLBX_CNT_X_CUSTOM_APP_ICQ);
-			else if (!strcmp (EVC_X_GROUPWISE, e_vcard_attribute_get_name (a))) // im groupwise
+			else if (!strcmp (EVC_X_GROUPWISE, e_vcard_attribute_get_name (a)))	/* im groupwise */
 				custom_field->app = g_string_new(KLBX_CNT_X_CUSTOM_APP_GROUPWISE);
-			else if (!strcmp (EVC_X_SKYPE, e_vcard_attribute_get_name (a))) 	// im skype
+			else if (!strcmp (EVC_X_SKYPE, e_vcard_attribute_get_name (a))) 	/* im skype */
 				custom_field->app = g_string_new(KLBX_CNT_X_CUSTOM_APP_SKYPE);
 		}
 
-		// test if name and app are set, if not, it is no x custom element and could produce errors due to multiple values etc.
+		/* test if name and app are set, if not, it is no x custom element and could produce errors due to multiple values etc. */
 		if (custom_field->app != NULL && custom_field->name != NULL) {
 			gchar *val = e_vcard_attribute_get_value(a);
 			if (val != NULL) {
@@ -571,12 +591,13 @@ add_custom_fields (const EContact *e_contact, I_contact* i_contact, GHashTable *
 				EVCardAttributeParam *eparam = paramlist->data;
 
 				if (eparam != NULL) {
+					GList* xml_str_list = NULL;
 					gchar *id_str = (gchar*)eparam;
 					gint id = strtol(id_str, (gchar**)0, 10);
 					gint *id_ptr = g_new0(gint, 1);
 					log_debug("found kolab store id %d", id);
 					*id_ptr = id;
-					GList* xml_str_list = g_hash_table_lookup(k_store_hash, id_ptr);
+					xml_str_list = g_hash_table_lookup(k_store_hash, id_ptr);
 					g_free(id_ptr);
 					xml_str_list = g_list_last(xml_str_list);
 					for (;xml_str_list != NULL; xml_str_list = xml_str_list->prev) {
@@ -588,7 +609,7 @@ add_custom_fields (const EContact *e_contact, I_contact* i_contact, GHashTable *
 			}
 
 		}
-		// next attribute in vcard
+		/* next attribute in vcard */
 		attr = attr->next;
 	}
 	g_list_free(attr);
@@ -604,23 +625,29 @@ kolab_store_handle_attachments(const EContact *e_contact, I_common* icommon)
 	for (; list != NULL; list = list->next) {
 		EVCardAttribute *attrib = (EVCardAttribute*)list->data;
 		if (strcmp(e_vcard_attribute_get_name (attrib), ICONTACT_KOLAB_STORE_ATTACHMENT) == 0) {
+			GString *str = NULL;
+
 			Kolab_conv_mail_part *mpart = g_new0(Kolab_conv_mail_part, 1);
 			EVCardAttributeParam* param = NULL;
 			GList *params = e_vcard_attribute_get_params(attrib);
 			for (; params != NULL; params = params->next) {
 				if (strcmp(e_vcard_attribute_param_get_name (params->data), ICONTACT_KOLAB_STORE_ATTACHMENT_MTYPE)== 0) {
+					GList *vlist = NULL;
+					gchar *mime_type = NULL;
 					param = (EVCardAttributeParam*)params->data;
-					GList *vlist = e_vcard_attribute_param_get_values(param);
-					gchar *mime_type = g_strdup((gchar*)vlist->data);
+					vlist = e_vcard_attribute_param_get_values(param);
+					mime_type = g_strdup((gchar*)vlist->data);
 					mpart->mime_type = mime_type;
 				} else if (strcmp(e_vcard_attribute_param_get_name (params->data), ICONTACT_KOLAB_STORE_ATTACHMENT_NAME)== 0) {
+					GList *vlist = NULL;
+					gchar *name = NULL;
 					param = (EVCardAttributeParam*)params->data;
-					GList *vlist = e_vcard_attribute_param_get_values(param);
-					gchar *name = g_strdup((gchar*)vlist->data);
+					vlist = e_vcard_attribute_param_get_values(param);
+					name = g_strdup((gchar*)vlist->data);
 					mpart->name = name;
 				}
 			}
-			GString *str = e_vcard_attribute_get_value_decoded (attrib);
+			str = e_vcard_attribute_get_value_decoded (attrib);
 			mpart->data = str->str;
 			mpart->length = str->len;
 
@@ -649,11 +676,12 @@ kolab_store_read_values (const EContact *e_contact, I_contact* i_contact)
 		EVCardAttribute *attrib = (EVCardAttribute*)list->data;
 		if (strcmp(e_vcard_attribute_get_name (attrib), ICONTACT_KOLAB_STORE) == 0) {
 			EVCardAttributeParam* param = NULL;
+			GString *str = NULL;
 			GList *params = e_vcard_attribute_get_params(attrib);
 			for (; params != NULL; params = params->next)
 				if (strcmp(e_vcard_attribute_param_get_name (params->data), ICONTACT_KOLAB_STORE_ID)== 0)
 					param = (EVCardAttributeParam*)params->data;
-			GString *str = e_vcard_attribute_get_value_decoded (attrib);
+			str = e_vcard_attribute_get_value_decoded (attrib);
 			if (param == NULL) {
 				kolab_store_add_element(i_contact->common, i_contact->common, strdup(str->str), FALSE);
 			} else {
@@ -664,9 +692,10 @@ kolab_store_read_values (const EContact *e_contact, I_contact* i_contact)
 					if (id == KOLAB_STORE_PTR_CONTACT_NAME)
 						kolab_store_add_element(i_contact->common, (gpointer) KOLAB_STORE_PTR_CONTACT_NAME, strdup(str->str), FALSE);
 					else {
-						gint *idptr = g_new0(gint, 1); // pointer must be different every time
+						GList *xml_str_list = NULL;
+						gint *idptr = g_new0(gint, 1); /* pointer must be different every time */
 						*idptr = id;
-						GList *xml_str_list = g_hash_table_lookup(hash, idptr);
+						xml_str_list = g_hash_table_lookup(hash, idptr);
 						xml_str_list = g_list_append(xml_str_list, (gpointer) strdup(str->str));
 						g_hash_table_insert(hash, idptr, xml_str_list);
 					}
@@ -702,35 +731,40 @@ static void
 kolab_store_restore_subnode_xml(I_contact *i_contact, gpointer parent_ptr,
 		const EContact *e_contact, EContactField e_field, GHashTable *k_store_hash)
 {
+	gchar *e_value = NULL;
+	GList *e_attr_list = NULL;
+	
 	log_debug("get vcard attributes for econtact field");
 
-	gchar *e_value = e_contact_get ((EContact*) e_contact, e_field); // params cannot be accessed here
-	GList* e_attr_list = e_contact_get_attributes ((EContact*)e_contact, e_field); // params can be accessed here but attribute set is bigger than before => use evalue to reduce attribute set.
+	e_value = e_contact_get ((EContact*) e_contact, e_field); /* params cannot be accessed here */
+	e_attr_list = e_contact_get_attributes ((EContact*)e_contact, e_field); /* params can be accessed here but attribute set is bigger than before => use evalue to reduce attribute set. */
 	for (; e_attr_list != NULL; e_attr_list = e_attr_list->next) {
+		GList *eparams = NULL;
 		EVCardAttribute *eattr = (EVCardAttribute*) e_attr_list->data;
 		if (e_vcard_attribute_is_single_valued(eattr)) {
 			gchar *avalue = e_vcard_attribute_get_value (eattr);
 			if (strcmp(avalue, e_value) != 0)
 				continue;
 		} else {
-			//log_warn("could not read kolab store id from multivalued vcard field");
+			/* log_warn("could not read kolab store id from multivalued vcard field"); */
 			break;
 		}
-		//log_debug("get vcard parameters for attribute %s", ((GString*)e_vcard_attribute_get_values_decoded(eattr)->data)->str);
-//		gchar *aname = e_vcard_attribute_get_name(eattr); //no new string is created here
-		GList *eparams = e_vcard_attribute_get_params (eattr);
+		/* log_debug("get vcard parameters for attribute %s", ((GString*)e_vcard_attribute_get_values_decoded(eattr)->data)->str); */
+		/* gchar *aname = e_vcard_attribute_get_name(eattr); no new string is created here */
+		eparams = e_vcard_attribute_get_params (eattr);
 		for (;eparams != NULL; eparams = eparams->next) {
 			if (strcmp(e_vcard_attribute_param_get_name (eparams->data), ICONTACT_KOLAB_STORE_ID) == 0) {
 				EVCardAttributeParam *eparam = eparams->data;
 				GList *epvlist = e_vcard_attribute_param_get_values(eparam);
 				if (epvlist != NULL) {
 					gchar *id_str = epvlist->data;
+					GList* xml_str_list = NULL;
 
 					gint id = strtol (id_str, (gchar**)0, 10);
 					gint *id_ptr = g_new0(gint, 1);
 					log_debug("found kolab store id %d", id);
 					*id_ptr = id;
-					GList* xml_str_list = g_hash_table_lookup(k_store_hash, id_ptr);
+					xml_str_list = g_hash_table_lookup(k_store_hash, id_ptr);
 					g_free(id_ptr);
 					xml_str_list = g_list_last(xml_str_list);
 					for (;xml_str_list != NULL; xml_str_list = xml_str_list->prev) {
@@ -773,7 +807,7 @@ address_type_e_to_i(EContactField e_addr_type)
 static Icontact_phone_type
 phone_type_e_to_i(GList *vcard_types)
 {
-	// set default phone type:
+	/* set default phone type: */
 	const Icontact_phone_type DEFAULT_TYPE = ICONTACT_PHONE_PRIMARY;
 
 	if (g_list_length(vcard_types) == 1) {
@@ -801,25 +835,25 @@ phone_type_e_to_i(GList *vcard_types)
 			return ICONTACT_PHONE_TTYTDD;
 		else if (strcmp(vcard_types->data, "VOICE") == 0)
 			return ICONTACT_PHONE_OTHER;
-		else if (strcmp(vcard_types->data, "FAX") == 0)		// OTHER_FAX
+		else if (strcmp(vcard_types->data, "FAX") == 0)		/* OTHER_FAX */
 			return ICONTACT_PHONE_BUSINESS_FAX;
 		else
 			return DEFAULT_TYPE;
 	} else {
-		// combinated types
+		/* combinated types */
 		if (g_list_find_custom(vcard_types, "WORK", (GCompareFunc)strcmp) != NULL) {
 			if (g_list_find_custom(vcard_types, "VOICE", (GCompareFunc)strcmp) != NULL) {
-				return ICONTACT_PHONE_BUSINESS_1;	// TYPE=WORK,VOICE
+				return ICONTACT_PHONE_BUSINESS_1;	/* TYPE=WORK,VOICE */
 			} else if (g_list_find_custom(vcard_types, "FAX", (GCompareFunc)strcmp) != NULL) {
-				return ICONTACT_PHONE_BUSINESS_FAX; // TYPE=WORK,FAX
+				return ICONTACT_PHONE_BUSINESS_FAX;	/* TYPE=WORK,FAX */
 			} else {
 				return DEFAULT_TYPE;
 			}
 		} else if (g_list_find_custom(vcard_types, "HOME", (GCompareFunc)strcmp) != NULL) {
 			if (g_list_find_custom(vcard_types, "VOICE", (GCompareFunc)strcmp) != NULL) {
-				return ICONTACT_PHONE_HOME_1;		// TYPE=HOME,VOICE
+				return ICONTACT_PHONE_HOME_1;		/* TYPE=HOME,VOICE */
 			} else if (g_list_find_custom(vcard_types, "FAX", (GCompareFunc)strcmp) != NULL) {
-				return ICONTACT_PHONE_HOME_FAX;		// TYPE=HOME,FAX
+				return ICONTACT_PHONE_HOME_FAX;		/* TYPE=HOME,FAX */
 			} else {
 				return DEFAULT_TYPE;
 			}
