@@ -53,16 +53,22 @@ static void recurrence_set_range (struct icalrecurrencetype *rec_type, Recurrenc
 void
 conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence)
 {
+	const gchar *location = NULL;
+	ECalComponentText *summary = NULL;
+	ECalComponentOrganizer *e_cal_comp_org = NULL;
+	ECalComponentDateTime *start_date = NULL;
+	GSList *attendee_list = NULL;
+	ECalComponentAttendee *ca = NULL;
+
 	conv_common_e_to_i (ectz, i_incidence->common);
 
-	//******************************************SET LOCATION************************************
-	const gchar *location;
+	/* ******************************************SET LOCATION************************************ */
 	e_cal_component_get_location(ectz->maincomp, &location);
 	if (location)
 		i_incidence->location = g_string_new(location);
 
-	//******************************************SET SUMMARY************************************
-	ECalComponentText *summary = g_new0(ECalComponentText, 1);
+	/* ******************************************SET SUMMARY************************************ */
+	summary = g_new0(ECalComponentText, 1);
 	e_cal_component_get_summary (ectz->maincomp, summary);
 	if (summary && summary->value && *summary->value)
 		i_incidence->summary = g_string_new(summary->value);
@@ -71,8 +77,8 @@ conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence
 
 	g_free(summary);
 
-	//******************************************SET ORGANIZER************************************
-	ECalComponentOrganizer *e_cal_comp_org = g_new0(ECalComponentOrganizer, 1);
+	/* ******************************************SET ORGANIZER************************************ */
+	e_cal_comp_org = g_new0(ECalComponentOrganizer, 1);
 	e_cal_component_get_organizer(ectz->maincomp, e_cal_comp_org);
 	if (e_cal_comp_org->cn)
 		i_incidence->organizer_display_name = g_string_new(e_cal_comp_org->cn);
@@ -81,7 +87,7 @@ conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence
 	g_free(e_cal_comp_org);
 
 
-	ECalComponentDateTime *start_date = g_new0(ECalComponentDateTime, 1);
+	start_date = g_new0(ECalComponentDateTime, 1);
 	e_cal_component_get_dtstart (ectz->maincomp, start_date);
 	if (start_date && start_date->value) {
 		localtime_to_utc(start_date, ectz->timezone);
@@ -91,20 +97,23 @@ conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence
 	e_cal_component_free_datetime(start_date);
 	g_free(start_date);
 
-	//******************************************SET ALARM / ADVANCED ALARM *****************************
+	/* ******************************************SET ALARM / ADVANCED ALARM ***************************** */
 
 	if (e_cal_component_has_alarms(ectz->maincomp)) {
-		//ECalComponentAlarms *eCalCompAlm = g_new0(ECalComponentAlarms, 1);
+		/* ECalComponentAlarms *eCalCompAlm = g_new0(ECalComponentAlarms, 1); */
 		GList *alarm_list = e_cal_component_get_alarm_uids(ectz->maincomp);
 
 		while (alarm_list) {
 			gchar *alarm_uid = ((gchar *)alarm_list->data);
 			ECalComponentAlarm *ecalcomp_alarm = e_cal_component_get_alarm(ectz->maincomp, alarm_uid);
 			if (ecalcomp_alarm) {
-				// new Alarm object to append later at i_incidence list
+				ECalComponentAlarmTrigger *trigger = NULL;
+				ECalComponentAlarmRepeat *repeat = NULL;
+
+				/* new Alarm object to append later at i_incidence list */
 				Alarm *alarm = g_new0(Alarm, 1);
 
-				// type / action
+				/* type / action */
 				ECalComponentAlarmAction action;
 				e_cal_component_alarm_get_action (ecalcomp_alarm, &action);
 				alarm->type = alarm_type_e_to_i(action);
@@ -116,42 +125,48 @@ conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence
 					g_free(text);
 				}
 				if (alarm->type == I_ALARM_TYPE_AUDIO) {
-					// set audio-file url
+					/* set audio-file url */
 					icalattach *attach;
 					e_cal_component_alarm_get_attach (ecalcomp_alarm, &attach);
 					alarm->audio_file = g_string_new(icalattach_get_url(attach));
 				}
 				if (alarm->type == I_ALARM_TYPE_PROCEDURE) {
-					alarm = new_alarm(I_ALARM_TYPE_PROCEDURE);
-
-					// set program
 					icalattach *attach;
+					ECalComponentText *text = NULL;
+
+					alarm = new_alarm(I_ALARM_TYPE_PROCEDURE);
+					
+					/* set program */
 					e_cal_component_alarm_get_attach (ecalcomp_alarm, &attach);
 					alarm->proc_param->program = g_string_new(icalattach_get_url(attach));
 
-					//set arguments
-					ECalComponentText *text = g_new0(ECalComponentText, 1);
+					/* set arguments */
+					text = g_new0(ECalComponentText, 1);
 					e_cal_component_alarm_get_description(ecalcomp_alarm, text);
 					alarm->proc_param->arguments = g_string_new(text->value);
 					g_free(text);
 				}
 				if (alarm->type == I_ALARM_TYPE_EMAIL) {
+					ECalComponentText *text = NULL;
+					GSList *attendee_list = NULL;
+					
 					alarm = new_alarm(I_ALARM_TYPE_EMAIL);
 
-					// set mail text
-					ECalComponentText *text = g_new0(ECalComponentText, 1);
+					/* set mail text */
+					text = g_new0(ECalComponentText, 1);
 					e_cal_component_alarm_get_description(ecalcomp_alarm, text);
 					alarm->email_param->mail_text = g_string_new(text->value);
 					g_free(text);
 
-					// set mail addresses
-					GSList *attendee_list = NULL;
+					/* set mail addresses */
 					e_cal_component_alarm_get_attendee_list(ecalcomp_alarm, &attendee_list);
 					for (; attendee_list; attendee_list = attendee_list->next) {
+						gchar* value = NULL;
+						
 						ECalComponentAttendee *ca = (ECalComponentAttendee *) attendee_list->data;
 
-						gchar* value = ca->value;
-						if (g_str_has_prefix(value, "MAILTO:"))// increase pointer by 7 to cut off prefix
+						value = ca->value;
+						if (g_str_has_prefix(value, "MAILTO:"))/* increase pointer by 7 to cut off prefix */
 							value +=7;
 
 						alarm->email_param->addresses = g_list_append(
@@ -162,56 +177,58 @@ conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence
 					generic_g_slist_free(&attendee_list, free_attendee);
 				}
 
-				// trigger
-				ECalComponentAlarmTrigger *trigger = g_new0(ECalComponentAlarmTrigger, 1);
+				/* trigger */
+				trigger = g_new0(ECalComponentAlarmTrigger, 1);
 				e_cal_component_alarm_get_trigger (ecalcomp_alarm, trigger);
 				if (trigger->type == E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_START)
-					alarm->start_offset = (icaldurationtype_as_int(trigger->u.rel_duration)/60); // (/60) as_int returns seconds, but kolab saved minutes
+					alarm->start_offset = (icaldurationtype_as_int(trigger->u.rel_duration)/60); /* (/60) as_int returns seconds, but kolab saved minutes */
 				if (trigger->type == E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_END)
-					alarm->end_offset = (icaldurationtype_as_int(trigger->u.rel_duration)/60); // (/60) as_int returns seconds, but kolab saved minutes
+					alarm->end_offset = (icaldurationtype_as_int(trigger->u.rel_duration)/60); /* (/60) as_int returns seconds, but kolab saved minutes */
 				if (trigger->type == E_CAL_COMPONENT_ALARM_TRIGGER_ABSOLUTE)
 				{
-					// TODO: Maybe calculate a relative trigger from incidence->startdate and evolution absolute trigger->u.abs_time -abs_time is icaltimetype, calculate in minutes?
-										// XXX: Not tested! & Both, Evolution and Kontact do not provide absolute alarm trigger. Just iCal secifies it.
-					//					// convert icaltimetype to date_time/time_t for use with time.h
-					//					Date_or_datetime *evo_date_time = NULL;
-					//					time_t *evo_abs_time = NULL;
-					//					i_cal_time_type_to_date_or_datetime(&trigger->u.abs_time, evo_date_time);
-					//					evo_abs_time = evo_date_time->date_time;
-					//
-					//
-					//					if (incidence->startDate->date_time != NULL)
-					//					{
-					//						// calculate difference in seconds with difftime when startDate is already date_time/time_t
-					//						time_t *i_start_time = incidence->startDate->date_time;
-					//						double diff = 0.0;
-					//						diff = difftime(*evo_abs_time, *i_start_time);	// returns seconds?
-					//					}
-					//					else if (incidence->startDate->date != NULL)
-					//					{
-					//						// convert startDate from GDate to date_time/time_t and then calculate difference
-					//						struct tm *stm = NULL;
-					//
-					//						/* First convert to a 'struct tm' */
-					//						g_date_to_struct_tm(incidence->startDate->date, stm); 	// gdate + 0:00:00
-					//
-					//						/* Then convert to number of seconds */
-					//						time_t *i_start_time = NULL;
-					//						i_start_time = mktime(stm);
-					//
-					//						double diff = 0.0;
-					//						diff = difftime(*evo_abs_time, *i_start_time); // returns seconds?
-					//					}
+					/* TODO: Maybe calculate a relative trigger from incidence->startdate and evolution absolute trigger->u.abs_time -abs_time is icaltimetype, calculate in minutes?
+					 *       XXX: Not tested! & Both, Evolution and Kontact do not provide absolute alarm trigger. Just iCal secifies it.
+					 *       convert icaltimetype to date_time/time_t for use with time.h
+					 */
+#if 0
+					Date_or_datetime *evo_date_time = NULL;
+					time_t *evo_abs_time = NULL;
+					i_cal_time_type_to_date_or_datetime(&trigger->u.abs_time, evo_date_time);
+					evo_abs_time = evo_date_time->date_time;
+
+					if (incidence->startDate->date_time != NULL)
+					{
+						/* calculate difference in seconds with difftime when startDate is already date_time/time_t */
+						time_t *i_start_time = incidence->startDate->date_time;
+						double diff = 0.0;
+						diff = difftime(*evo_abs_time, *i_start_time);	/* returns seconds? */
+					}
+					else if (incidence->startDate->date != NULL)
+					{
+						/* convert startDate from GDate to date_time/time_t and then calculate difference */
+						struct tm *stm = NULL;
+
+						/* First convert to a 'struct tm' */
+						g_date_to_struct_tm(incidence->startDate->date, stm); 	/* gdate + 0:00:00 */
+
+						/* Then convert to number of seconds */
+						time_t *i_start_time = NULL;
+						i_start_time = mktime(stm);
+
+						double diff = 0.0;
+						diff = difftime(*evo_abs_time, *i_start_time); /* returns seconds? */
+					}
+#endif
 				}
 				g_free(trigger);
 
-				// repeat (count & interval)
-				ECalComponentAlarmRepeat *repeat = g_new0(ECalComponentAlarmRepeat, 1);
+				/* repeat (count & interval) */
+				repeat = g_new0(ECalComponentAlarmRepeat, 1);
 				e_cal_component_alarm_get_repeat (ecalcomp_alarm, repeat);
 				if (repeat->repetitions)
 					alarm->repeat_count = repeat->repetitions;
 				if (icaldurationtype_is_null_duration(repeat->duration) == 0)
-					alarm->repeat_interval = (icaldurationtype_as_int(repeat->duration)/60); // (/60) as_int returns seconds, but kolab saved minutes
+					alarm->repeat_interval = (icaldurationtype_as_int(repeat->duration)/60); /* (/60) as_int returns seconds, but kolab saved minutes */
 
 				i_incidence->advanced_alarm = g_list_append( i_incidence->advanced_alarm, (Alarm *) alarm);
 
@@ -225,26 +242,25 @@ conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence
 		generic_g_list_free(&alarm_list, free_alarm);
 	}
 
-	//******************************************SET ATTENDEE LIST*******************************************************************************
-	GSList *attendee_list = NULL;
-	ECalComponentAttendee *ca;
+	/* ******************************************SET ATTENDEE LIST******************************************************************************* */
 
 	e_cal_component_get_attendee_list(ectz->maincomp, &attendee_list);
 
 	while (attendee_list) {
+		Attendee *attendee = g_new0(Attendee, 1);
+
 		ca = (ECalComponentAttendee *) attendee_list->data;
 
-		Attendee *attendee = g_new0(Attendee, 1);
 		if (ca->cn)
 			attendee->display_name = g_string_new(ca->cn);
 
 		if (g_str_has_prefix(ca->value, "MAILTO:"))
-			attendee->smtp_address = g_string_new(ca->value+7); // increase pointer by 7 to cut off prefix
+			attendee->smtp_address = g_string_new(ca->value+7); /* increase pointer by 7 to cut off prefix */
 		else
 			attendee->smtp_address = g_string_new(ca->value);
 
 		attendee->request_response = ca->rsvp;
-		// TODO: Incidence: invitation_sent: get from kolab-store?
+		/* TODO: Incidence: invitation_sent: get from kolab-store? */
 		attendee->role = incidence_role_e_to_i(ca->role);
 		attendee->status = incidence_status_e_to_i(ca->status);
 		attendee->cutype = incidence_cutype_e_to_i(ca->cutype);
@@ -412,9 +428,11 @@ recurrence_type_e_to_i (struct icalrecurrencetype *rec_type)
 static void
 recurrence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence)
 {
-	//******************************************SET RECURRENCE*******************************************************************************
-	//******************************************SET RECURRENCE EXCLUSIONS********************************************************************
-	GSList *exdate_list;
+	GSList *exdate_list = NULL;
+	GSList *rec_list = NULL;
+
+	/* ******************************************SET RECURRENCE******************************************************************************* */
+	/* ******************************************SET RECURRENCE EXCLUSIONS******************************************************************** */
 	e_cal_component_get_exdate_list (ectz->maincomp, &exdate_list);
 	if (exdate_list)
 		i_incidence->recurrence = new_recurrence();
@@ -431,14 +449,14 @@ recurrence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence)
 		exdate_list = exdate_list->next;
 	}
 	g_slist_free(exdate_list);
-	//******************************************SET RECURRENCE CYCLE********************************************************************
-	GSList *rec_list = NULL;
+	/* ******************************************SET RECURRENCE CYCLE******************************************************************** */
 	e_cal_component_get_rrule_list (ectz->maincomp, &rec_list);
 
 	while (rec_list != NULL) {
+		struct icalrecurrencetype *rec_type = (struct icalrecurrencetype *) rec_list->data;
+
 		if (i_incidence->recurrence == NULL)
 			i_incidence->recurrence = new_recurrence();
-		struct icalrecurrencetype *rec_type = (struct icalrecurrencetype *) rec_list->data;
 
 		i_incidence->recurrence->recurrence_cycle = recurrence_type_e_to_i (rec_type);
 		recurrence_set_range (rec_type, i_incidence->recurrence);
@@ -446,16 +464,17 @@ recurrence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence)
 
 		add_recurrence_subfields (i_incidence, rec_type);
 
-		// remapping of missing I_REC_CYCLE_YEARLY_WEEKDAY support in evolution
+		/* remapping of missing I_REC_CYCLE_YEARLY_WEEKDAY support in evolution */
 		if (rec_type->freq == ICAL_MONTHLY_RECURRENCE
 				&& rec_type->by_day[0] != ICAL_RECURRENCE_ARRAY_MAX
 				&& rec_type->by_set_pos[0] != ICAL_RECURRENCE_ARRAY_MAX
 				&& rec_type->by_set_pos[1] == ICAL_RECURRENCE_ARRAY_MAX
 				&& i_incidence->recurrence->interval == 12) {
+			gint month = 0;
+
 			i_incidence->recurrence->recurrence_cycle = I_REC_CYCLE_YEARLY_WEEKDAY;
 			i_incidence->recurrence->interval = 1;
 
-			gint month = 0;
 			if (i_incidence->start_date && i_incidence->start_date->date)
 				month = g_date_get_month(i_incidence->start_date->date);
 			else if (i_incidence->start_date && i_incidence->start_date->date_time != NULL) {
@@ -474,17 +493,18 @@ recurrence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence)
 				i_incidence->recurrence->month = ts->tm_mon + 1;
 				i_incidence->recurrence->day_number = ts->tm_mday;
 			}
-
-//			icalcomponent *icomp = e_cal_component_get_icalcomponent(ectz->maincomp);
-//			icalcomponent_kind ical_kind = icalcomponent_isa(icomp);
-//			if (ical_kind == ICAL_VTODO_COMPONENT) {
-//				ECalComponentDateTime *dt;
-//				e_cal_component_get_due(ectz->maincomp, dt);
-//				if (dt) {
-//					i_incidence->recurrence->month = dt->value->month;
-//					i_incidence->recurrence->day_number = dt->value->day;
-//				}
-//			}
+#if 0
+			icalcomponent *icomp = e_cal_component_get_icalcomponent(ectz->maincomp);
+			icalcomponent_kind ical_kind = icalcomponent_isa(icomp);
+			if (ical_kind == ICAL_VTODO_COMPONENT) {
+				ECalComponentDateTime *dt;
+				e_cal_component_get_due(ectz->maincomp, dt);
+				if (dt) {
+					i_incidence->recurrence->month = dt->value->month;
+					i_incidence->recurrence->day_number = dt->value->day;
+				}
+			}
+#endif
 		}
 
 		g_free(rec_type);
@@ -511,9 +531,11 @@ add_recurrence_subfields (I_incidence *i_incidence, struct icalrecurrencetype *r
 			i_incidence->recurrence->day_number = rec_type->by_set_pos[0];
 		recurrence_set_by_weekday(rec_type, i_incidence->recurrence);
 	} else if (i_incidence->recurrence->recurrence_cycle == I_REC_CYCLE_YEARLY_MONTHDAY) {
-		// disabled, cannot be properly handled by Evolution
-//		recurrence_set_by_month_day(rec_type, i_incidence);
-//		recurrence_set_by_month(rec_type, i_incidence->recurrence);
+		/* disabled, cannot be properly handled by Evolution */
+#if 0
+		recurrence_set_by_month_day(rec_type, i_incidence);
+		recurrence_set_by_month(rec_type, i_incidence->recurrence);
+#endif
 	} else if (i_incidence->recurrence->recurrence_cycle == I_REC_CYCLE_YEARLY_YEARDAY) {
 		recurrence_set_by_year_day(rec_type, i_incidence->recurrence);
 	} else if (i_incidence->recurrence->recurrence_cycle == I_REC_CYCLE_YEARLY_WEEKDAY) {
@@ -588,7 +610,7 @@ recurrence_set_range(struct icalrecurrencetype *rec_type, Recurrence *recurrence
 		recurrence->range_number = g_new0(gint, 1);
 		*recurrence->range_number = rec_type->count;
 	} else {
-		// infinite recurrence
+		/* infinite recurrence */
 	}
 }
 
