@@ -32,7 +32,7 @@
  */
 
 #include "priv-kolab.h"
-#include "kolab.h" // public part of this file
+#include "kolab.h" /* public part of this file */
 #include "../util.h"
 
 /*
@@ -68,19 +68,22 @@ static Icontact_phone_type phone_type_k_to_icontact(gchar *k_phone_type);
 I_contact*
 conv_kolab_conv_mail_to_I_contact (const Kolab_conv_mail* k_contact, GError** error)
 {
+	I_contact *i_contact = NULL;
+	xmlNodePtr node = NULL, n_ptr;
+	xmlDocPtr doc = NULL;
+	
 	log_debug ("\nconv_kolab_conv_mail_to_I_contact(): convert Kolab_conv_mail to I_contact.");
 
 	if (*error != NULL)
 		return NULL;
-	// get parsed kolab XML
-	I_contact *i_contact = new_i_contact ();
-	xmlDocPtr doc = util_get_kolab_xml_part(k_contact, &i_contact->common->kolab_attachment_store, error);
+	/* get parsed kolab XML */
+	i_contact = new_i_contact ();
+	doc = util_get_kolab_xml_part(k_contact, &i_contact->common->kolab_attachment_store, error);
 
 	if (*error != NULL)
 		return NULL;
 
-	// find root node
-	xmlNodePtr node = NULL, n_ptr;
+	/* find root node */
 	for (n_ptr = doc->children; n_ptr != NULL; n_ptr = n_ptr->next)
 		if (n_ptr->type == XML_ELEMENT_NODE &&
 				g_strcmp0((gchar*)n_ptr->name, KLB_CNT) == 0)
@@ -127,8 +130,8 @@ conv_kolab_conv_mail_to_I_contact (const Kolab_conv_mail* k_contact, GError** er
 static void
 process_contact_k_to_i (I_contact *i_contact, const xmlNodePtr node, GError** error)
 {
-	// iterate over all child elements of event_node an process them
-	xmlNodePtr n_ptr; // used in for loop
+	/* iterate over all child elements of event_node an process them */
+	xmlNodePtr n_ptr; /* used in for loop */
 	for (n_ptr = node->children; n_ptr != NULL; n_ptr = n_ptr->next) {
 		if (n_ptr->type == XML_ELEMENT_NODE) {
 			gboolean node_processed = read_contact_element(i_contact, n_ptr, error);
@@ -156,14 +159,16 @@ process_contact_k_to_i (I_contact *i_contact, const xmlNodePtr node, GError** er
 static void
 process_attachments_k_to_i (I_contact* i_contact, GError** error)
 {
+	GList *attach = NULL;
+	
 	g_assert(error != NULL && *error == NULL);
-	//iteration of kolabXmlMailArray for adding attachments
+	/* iteration of kolabXmlMailArray for adding attachments */
 
-	GList *attach = i_contact->common->kolab_attachment_store;
+	attach = i_contact->common->kolab_attachment_store;
 	while (attach) {
 		Kolab_conv_mail_part *mail_part = attach->data;
 
-//		if (i_contact->picture_name && strcmp (i_contact->picture_name->str, mail_part->name) == 0) {
+		/* if (i_contact->picture_name && strcmp (i_contact->picture_name->str, mail_part->name) == 0) { */
 		if (i_contact->photo && i_contact->photo->name && strcmp (i_contact->photo->name, mail_part->name) == 0) {
 			g_free(i_contact->photo->name);
 			g_free(i_contact->photo);
@@ -192,7 +197,7 @@ static gboolean
 read_contact_element(I_contact *i_contact, xmlNodePtr node, GError **error)
 {
 	if (common_k_to_i(i_contact->common, node, error)) {
-		return handle_sensitivity(i_contact, node);	// node processed if it is not sensitivity
+		return handle_sensitivity(i_contact, node);	/* node processed if it is not sensitivity */
 	} else if (*error != NULL)
 		return FALSE;
 
@@ -201,7 +206,7 @@ read_contact_element(I_contact *i_contact, xmlNodePtr node, GError **error)
 		handle_element_string(KLB_CNT_FREE_BUSY_URL, &i_contact->free_busy_url, node) ||
 		handle_element_string(KLB_CNT_ORGANIZATION, &i_contact->organization, node) ||
 		handle_element_string(KLB_CNT_WEB_PAGE, &i_contact->web_page, node) ||
-		// im-address: not available in Evolution, written in kolab store
+		/* im-address: not available in Evolution, written in kolab store */
 		handle_element_string(KLB_CNT_DEPARTMENT, &i_contact->department, node) ||
 		handle_element_string(KLB_CNT_OFFICE_LOCATION, &i_contact->office_location, node) ||
 		handle_element_string(KLB_CNT_PROFESSION, &i_contact->profession, node) ||
@@ -213,14 +218,15 @@ read_contact_element(I_contact *i_contact, xmlNodePtr node, GError **error)
 		handle_element_date(KLB_CNT_BIRTHDAY, &i_contact->birthday, node) ||
 		handle_element_date(KLB_CNT_ANNIVERSARY, &i_contact->anniversary, node) ||
 		handle_picture_name(i_contact, node) ||
-//		handle_element_string(KLB_CNT_PICTURE, &i_contact->picture_name, node) ||
-		// children: not available in Evolution, written in kolab store
-		// gender: not available in Evolution, written in kolab store
-		// language: not available in Evolution, written in kolab store
+		/* handle_element_string(KLB_CNT_PICTURE, &i_contact->picture_name, node) || */
+		/* children: not available in Evolution, written in kolab store
+		 * gender: not available in Evolution, written in kolab store
+		 * language: not available in Evolution, written in kolab store
+		 */
 		handle_element_phone (i_contact, node) ||
 		handle_element_email (i_contact, node) ||
 		handle_element_address (i_contact, node) ||
-		// preferred address: not available in Evolution, written in kolab store
+		/* preferred address: not available in Evolution, written in kolab store */
 		handle_element_double (KLB_CNT_LATITUDE, &i_contact->latitude, node) ||
 		handle_element_double (KLB_CNT_LONGITUDE, &i_contact->longitude, node) ||
 		handle_element_string(KLB_CNT_NAME_SUFFIX, &i_contact->suffix, node) ||
@@ -231,10 +237,11 @@ static gboolean
 handle_sensitivity(I_contact *i_contact, xmlNodePtr node)
 {
 	if (strcmp ((gchar*) node->name, KLB_CMN_SENSITIVITY) != 0)
-		return TRUE;	// Not sensitivity node, so node is processed.
+		return TRUE;	/* Not sensitivity node, so node is processed. */
 
-	// Otherwise it is the sensitivity node and will be reset to null,
-	// and returned false for not processed, that it will be put in kolab store.
+	/* Otherwise it is the sensitivity node and will be reset to null,
+	 * and returned false for not processed, that it will be put in kolab store.
+	 */
 	i_contact->common->sensitivity = ICOMMON_SENSITIVITY_NULL;
 	return FALSE;
 }
@@ -242,19 +249,22 @@ handle_sensitivity(I_contact *i_contact, xmlNodePtr node)
 static gboolean
 handle_picture_name (I_contact *i_contact, xmlNodePtr node)
 {
+	gchar *picture_name = NULL;
+	
 	if (strcmp ((gchar*) node->name, KLB_CNT_PICTURE) != 0)
-		return FALSE;	// Not a photo_name node
+		return FALSE;	/* Not a photo_name node */
 
-	char* picture_name = xml_get_node_text(node);
+	picture_name = xml_get_node_text(node);
 
-	// create mail part and set name if not empty
+	/* create mail part and set name if not empty */
 	if (*picture_name) {
 		i_contact->photo = g_new0(Kolab_conv_mail_part, 1);
 		i_contact->photo->name = g_strdup_printf("%s", picture_name);
 	}
-//	else
-//		i_contact->photo = NULL;
-
+#if 0
+	else
+		i_contact->photo = NULL;
+#endif
 	return TRUE;
 }
 
@@ -265,12 +275,16 @@ handle_picture_name (I_contact *i_contact, xmlNodePtr node)
 static gboolean
 handle_element_custom (I_contact *i_contact, const xmlNodePtr node)
 {
-	if (strcmp ((gchar*) node->name, KLBX_CNT_X_CUSTOM_LIST) != 0)
-		return FALSE;
-
 	xmlChar* node_value = NULL;
 	xmlChar* node_app = NULL;
 	xmlChar* node_name = NULL;
+	gchar *str = NULL;
+	gchar *delim = "\356\200\200";	/*  separator written by Kontact (=EE=84=A0) */
+	gchar **tokens = NULL;
+	gint i;
+	
+	if (strcmp ((gchar*) node->name, KLBX_CNT_X_CUSTOM_LIST) != 0)
+		return FALSE;
 
 	if (xmlHasProp (node, (xmlChar*) KLBX_CNT_X_CUSTOM_VALUE))
 		node_value = xmlGetProp (node, (xmlChar*) KLBX_CNT_X_CUSTOM_VALUE);
@@ -279,15 +293,14 @@ handle_element_custom (I_contact *i_contact, const xmlNodePtr node)
 	if (xmlHasProp (node, (xmlChar*) KLBX_CNT_X_CUSTOM_NAME))
 		node_name = xmlGetProp (node, (xmlChar*) KLBX_CNT_X_CUSTOM_NAME);
 
-	// split value string if delimiter is available
-	// Kontact saves values of datasets from the same type in same xml tag value with delimiter
-	gchar *str = (gchar*)node_value;
-	gchar *delim = "\356\200\200";	//  separator written by Kontact (=EE=84=A0)
+	/* split value string if delimiter is available
+	 * Kontact saves values of datasets from the same type in same xml tag value with delimiter
+	 */
+	str = (gchar*)node_value;
+	tokens = str_split(str, delim);
 
-	gchar **tokens = str_split(str, delim);
-	gint i;
 	for (i = 0; tokens[i]; ++i) {
-		//Add a new custom field to the contact object member custom_list
+		/* Add a new custom field to the contact object member custom_list */
 		Custom *custom_field = g_new (Custom, 1);
 		custom_field->value = g_string_new(tokens[i]);
 		custom_field->app = g_string_new ((gchar *) node_app);
@@ -295,7 +308,7 @@ handle_element_custom (I_contact *i_contact, const xmlNodePtr node)
 
 		i_contact->custom_list = g_list_append (i_contact->custom_list, (Custom *) custom_field);
 
-		//printf("%i: '%s'\n", i, tokens[i]);
+		/* printf("%i: '%s'\n", i, tokens[i]); */
 	}
 
 	free_str_tokens(tokens);
@@ -322,16 +335,17 @@ handle_element_custom (I_contact *i_contact, const xmlNodePtr node)
 static gboolean
 handle_element_phone (I_contact *i_contact, const xmlNodePtr node)
 {
+	const guint max_numbers = 8; /* maximum values that can be shown by evolution, remaining numbers in kolab-store */
+	xmlNodePtr text = NULL;
+	xmlNodePtr child = NULL;
+	xmlNodePtr child_contents = NULL;
+	Phone_number *phone_nr = NULL;
+
 	if (strcmp ((gchar*) node->name, KLB_CNT_PHONE_LIST) != 0)
 		return FALSE;
 
-	const guint max_numbers = 8; // maximum values that can be shown by evolution, remaining numbers in kolab-store
-
-	xmlNodePtr text = node->children;
-	xmlNodePtr child = NULL;
-	xmlNodePtr child_contents = NULL;
-
-	Phone_number *phone_nr = g_new0 (Phone_number, 1);
+	text = node->children;
+	phone_nr = g_new0 (Phone_number, 1);
 
 	do {
 		child = text->next;
@@ -347,33 +361,34 @@ handle_element_phone (I_contact *i_contact, const xmlNodePtr node)
 
 	} while (text->next != NULL);
 
-	// special case for combined types with primary
+	/* special case for combined types with primary */
 	if (phone_nr->type == ICONTACT_PHONE_BUSINESS_2 || phone_nr->type == ICONTACT_PHONE_HOME_2) {
-		// if type that has to be saved a two nodes, there must be 2 free places in array
+		/* if type that has to be saved a two nodes, there must be 2 free places in array */
 		if (g_list_length(i_contact->phone_numbers) < max_numbers-1) {
+			Phone_number *primary_phone = NULL;
 
-			if (phone_nr->type == ICONTACT_PHONE_BUSINESS_2)	// business 2 = business 1 & primary
+			if (phone_nr->type == ICONTACT_PHONE_BUSINESS_2)	/* business 2 = business 1 & primary */
 				phone_nr->type = ICONTACT_PHONE_BUSINESS_1;
-			else if (phone_nr->type == ICONTACT_PHONE_HOME_2) 	// home 2 = home 1 & primary
+			else if (phone_nr->type == ICONTACT_PHONE_HOME_2) 	/* home 2 = home 1 & primary */
 				phone_nr->type = ICONTACT_PHONE_HOME_1;
 
 			i_contact->phone_numbers = g_list_append (i_contact->phone_numbers, (Phone_number *) phone_nr);
 
-			// additional primary node							// + primary
-			Phone_number *primary_phone = g_new0 (Phone_number, 1);
+			/* additional primary node */							/* + primary */
+			primary_phone = g_new0 (Phone_number, 1);
 			primary_phone->type = ICONTACT_PHONE_PRIMARY;
 			primary_phone->number = g_strdup(phone_nr->number);
 			i_contact->phone_numbers = g_list_append (i_contact->phone_numbers, (Phone_number *) primary_phone);
 		} else  {
-			// array full, put in kolab store
+			/* array full, put in kolab store */
 			free_phone_number((void **) &phone_nr);
 			i_kolab_store_add_xml_element(i_contact->common, i_contact->common, node);
 		}
 	} else if (g_list_length(i_contact->phone_numbers) < max_numbers) {
-		// if normal type, saved as one node, there must be 1 free place in array
+		/* if normal type, saved as one node, there must be 1 free place in array */
 		i_contact->phone_numbers = g_list_append (i_contact->phone_numbers, (Phone_number *) phone_nr);
 	} else {
-		// array full, put in kolab store
+		/* array full, put in kolab store */
 		free_phone_number((void **) &phone_nr);
 		i_kolab_store_add_xml_element(i_contact->common, i_contact->common, node);
 	}
@@ -394,17 +409,19 @@ handle_element_phone (I_contact *i_contact, const xmlNodePtr node)
 static gboolean
 handle_element_email (I_contact *i_contact, const xmlNodePtr node)
 {
+	xmlNodePtr text = NULL;
+	xmlNodePtr child = NULL;
+	xmlNodePtr child_contents = NULL;
+	Email *email = NULL;
+	
 	if (strcmp ((gchar*) node->name, KLB_CNT_EMAIL_LIST) != 0)
 		return FALSE;
 
 	if (g_list_length(i_contact->emails) >= 4)
 		return FALSE;
 
-	xmlNodePtr text = node->children;
-	xmlNodePtr child = NULL;
-	xmlNodePtr child_contents = NULL;
-
-	Email *email = g_new0 (Email, 1);
+	text = node->children;
+	email = g_new0 (Email, 1);
 
 	while (text != NULL && text->next != NULL) {
 
@@ -437,14 +454,16 @@ handle_element_email (I_contact *i_contact, const xmlNodePtr node)
 static gboolean
 handle_element_address (I_contact *i_contact, const xmlNodePtr node)
 {
+	Address *address = NULL;
+	xmlNodePtr text = NULL;
+	xmlNodePtr child = NULL;
+	xmlNodePtr child_contents = NULL;
+	
 	if (strcmp ((gchar*) node->name, KLB_CNT_ADDRESS_LIST) != 0)
 		return FALSE;
 
-	Address *address = g_new0 (Address, 1);
-
-	xmlNodePtr text = node->children;
-	xmlNodePtr child = NULL;
-	xmlNodePtr child_contents = NULL;
+	address = g_new0 (Address, 1);
+	text = node->children;
 
 	do {
 		child = text->next;
@@ -468,16 +487,16 @@ handle_element_address (I_contact *i_contact, const xmlNodePtr node)
 			i_kolab_store_add_xml_element(i_contact->common, address, child);
 
 		text = child->next;
-		//log_debug("\nBBB: %s-%s-%s-%s",text->name, text->content, child->name, child->content);
-		//log_debug("\nAAA%s", (char *)text->next);
+		/* log_debug("\nBBB: %s-%s-%s-%s",text->name, text->content, child->name, child->content); */
+		/* log_debug("\nAAA%s", (char *)text->next); */
 
 	} while (text->next != NULL);
 
-	// test if element of same type still in address list (evolution can just handle one of each type)
+	/* test if element of same type still in address list (evolution can just handle one of each type) */
 	if (g_list_find_custom(i_contact->addresses, &address->type, (GCompareFunc)strcmp)) {
-		// TODO Remove, if needed, child-element from store, because in this case full address will be put in kolab store.
-		// g_hash_table_remove(i_contact->common->kolab_store, child);
-		return FALSE;	// return element not handled, then will be put in kolab store
+		/* TODO Remove, if needed, child-element from store, because in this case full address will be put in kolab store. */
+		/* g_hash_table_remove(i_contact->common->kolab_store, child); */
+		return FALSE;	/* return element not handled, then will be put in kolab store */
 	}
 	else
 	{
@@ -496,11 +515,12 @@ handle_element_address (I_contact *i_contact, const xmlNodePtr node)
 static gboolean
 handle_contact_name (I_contact *i_contact, xmlNodePtr node)
 {
+	xmlNodePtr n_ptr; /* used in for loop */
+
 	if (strcmp ((gchar*) node->name, KLB_CNT_NAME) != 0)
 		return FALSE;
 
-	// iterate over all child elements of node an process them
-	xmlNodePtr n_ptr; // used in for loop
+	/* iterate over all child elements of node an process them */
 	for (n_ptr = node->children; n_ptr != NULL; n_ptr = n_ptr->next) {
 		if (n_ptr->type == XML_ELEMENT_NODE) {
 			if(
@@ -508,7 +528,7 @@ handle_contact_name (I_contact *i_contact, xmlNodePtr node)
 				handle_element_string(KLB_CNT_NAME_MIDDLE_NAMES, &i_contact->middle_names, n_ptr) ||
 				handle_element_string(KLB_CNT_NAME_LAST_NAME, &i_contact->last_name, n_ptr) ||
 				handle_element_string(KLB_CNT_NAME_FULL_NAME, &i_contact->full_name, n_ptr) ||
-				// TODO: Contact: <initials> ?!!!
+				/* TODO: Contact: <initials> ?!!! */
 				handle_element_string(KLB_CNT_NAME_PREFIX, &i_contact->prefix, n_ptr) ||
 				handle_element_string(KLB_CNT_NAME_SUFFIX, &i_contact->suffix, n_ptr)
 			)
@@ -588,5 +608,3 @@ phone_type_k_to_icontact(gchar *k_phone_type)
 	else
 		return ICONTACT_PHONE_PRIMARY;
 }
-
-
