@@ -42,7 +42,7 @@
  * [1] http://kolab.org/doc/kolabformat-2.0rc7-html/
  */
 
-// ------------------------------------------------------------- common fields {
+/* ------------------------------------------------------------- common fields { */
 
 #define KLB_CMN_UID                                     "uid"
 #define KLB_CMN_BODY                                    "body"
@@ -50,7 +50,7 @@
 #define KLB_CMN_CREATION_DATE                           "creation-date"
 #define KLB_CMN_LAST_MODIFICATION_DATE                  "last-modification-date"
 
-// tag from Kontact, showing if body text is with or without html
+/* tag from Kontact, showing if body text is with or without html */
 #define KLBX_CMN_RICHTEXT								"knotes-richtext"
 
 #define KLB_CMN_SENSITIVITY                             "sensitivity"
@@ -66,11 +66,11 @@
 #define KLB_CMN_EVO_STORE                               "x-kolabconv-store"
 
 
-// ------------------------------------------------------- own timezone fields }
+/* ------------------------------------------------------- own timezone fields } */
 
-// ------------------------------------------------------------- common fields }
+/* ------------------------------------------------------------- common fields } */
 
-// ---------------------------------------------------------- incidence fields {
+/* ---------------------------------------------------------- incidence fields { */
 
 #define KLB_INC_SUMMARY                                 "summary"
 #define KLB_INC_LOCATION                                "location"
@@ -86,7 +86,7 @@
 #define KLB_INC_START_DATE                              "start-date"
 #define KLB_INC_ALARM                                   "alarm"
 
-// ----------------------------------------------------- advanced alarm fields {
+/* ----------------------------------------------------- advanced alarm fields { */
 
 /* advanced alarm fields are not defined in the kolab format specification
  * see: http://www.kolab.org/pipermail/kolab-format/2008-September/000873.html
@@ -113,7 +113,7 @@
 #define KLBX_INC_ADV_ALARM_REPEAT_COUNT                 "repeat-count"
 #define KLBX_INC_ADV_ALARM_REPEAT_INTERVAL              "repeat-interval"
 
-// ----------------------------------------------------- advanced alarm fields }
+/* ----------------------------------------------------- advanced alarm fields } */
 
 #define KLB_INC_RECURRENCE                              "recurrence"
 
@@ -188,7 +188,7 @@
 /** not part of the kolab format specification but written by kontact */
 #define KLBX_INC_ATTENDEE_INVITATION_SENT               "invitation-sent"
 
-// evolution alarm
+/* evolution alarm */
 #define KLBC_INC_X_EVOLUTION_ALARM_UID					"x-evolution-alarm-uid"
 #define	KLBC_INC_DESCRIPTION							"description"
 #define	KLBC_INC_ACTION									"action"
@@ -200,13 +200,15 @@
 #define	KLBC_INC_CUTYPE									"cutype"
 #define	KLBC_INC_LANGUAGE								"language"
 
-//Undecided fields
-//#define	INCIDENCE_PILOT_SYNC_STATUS					"pilot-sync-status"
-//#define	INCIDENCE_DESCRIPTION						""
+/* Undecided fields */
+#if 0
+#define	INCIDENCE_PILOT_SYNC_STATUS					"pilot-sync-status"
+#define	INCIDENCE_DESCRIPTION						""
+#endif
 
-// ---------------------------------------------------------- incidence fields }
+/* ---------------------------------------------------------- incidence fields } */
 
-// ------------------------------------------------------------ contact fields {
+/* ------------------------------------------------------------ contact fields { */
 
 #define KLB_CNT											"contact"
 
@@ -241,7 +243,7 @@
 #define KLB_CNT_GENDER									"gender"
 #define KLB_CNT_LANGUAGE								"language"
 
-#define KLB_CNT_PHONE_LIST								"phone"			// phone list
+#define KLB_CNT_PHONE_LIST								"phone"			/* phone list */
 #define KLB_CNT_PHONE_TYPE								"type"
 #define KLB_CNT_PHONE_TYPE_ASSISTANT					"assistant"
 #define KLB_CNT_PHONE_TYPE_BUSINESS_1					"business1"
@@ -263,14 +265,14 @@
 #define KLB_CNT_PHONE_TYPE_TTYTDD						"ttytdd"
 #define KLB_CNT_PHONE_NUMBER							"number"
 
-#define KLB_CNT_EMAIL_LIST								"email"			// email list
+#define KLB_CNT_EMAIL_LIST								"email"			/* email list */
 #define KLB_CNT_EMAIL_DISPLAY_NAME						"display-name"
 #define KLB_CNT_EMAIL_SMTP_ADDRESS						"smtp-address"
 #define KLBC_CNT_EMAIL_TYPE								"x-evolution-email-type"
 #define KLBC_CNT_EMAIL_X_EVOLUTION_UI_SLOT				"x-evolution-ui-slot"
 #define KLBC_CNT_EMAIL_X_MOZILLA_HTML					"x-mozilla-html"
 
-#define KLB_CNT_ADDRESS_LIST							"address"		// address list
+#define KLB_CNT_ADDRESS_LIST							"address"		/* address list */
 #define KLB_CNT_ADDRESS_TYPE							"type"
 #define KLB_CNT_ADDRESS_TYPE_HOME						"home"
 #define KLB_CNT_ADDRESS_TYPE_BUSINESS					"business"
@@ -283,7 +285,7 @@
 #define KLBX_CNT_ADDRESS_POBOX							"pobox"
 #define KLB_CNT_PREFERRED_ADDRESS						"preferred-address"
 
-// GEO
+/* GEO */
 #define KLB_CNT_LATITUDE								"latitude"
 #define KLB_CNT_LONGITUDE								"longitude"
 
@@ -315,9 +317,9 @@
 #define KLBC_CNT_X_EVOLUTION_LIST_SHOW_ADDRESSES		"x-evolution-list-show-addresses"
 
 
-// ------------------------------------------------------------ contact fields }
+/* ------------------------------------------------------------ contact fields } */
 
-// -------------------------------------------------------------- event fields {
+/* -------------------------------------------------------------- event fields { */
 
 #define KLB_EVENT										"event"
 
@@ -346,9 +348,9 @@
 #define KLBC_INCIDENCE_ATTENDEE_TYPE_RESOURCE                     "resource"
 #define KLBC_INCIDENCE_ATTENDEE_TYPE_ROOM                     		"room"
 
-// -------------------------------------------------------------- event fields }
+/* -------------------------------------------------------------- event fields } */
 
-// --------------------------------------------------------------- task fields {
+/* --------------------------------------------------------------- task fields { */
 
 #define KLB_TASK										"task"
 
@@ -366,9 +368,9 @@
 
 #define KLBX_TASK_COMPLETED_DATE								"x-completed-date"
 
-// --------------------------------------------------------------- task fields }
+/* --------------------------------------------------------------- task fields } */
 
-// --------------------------------------------------------------- note fields {
+/* --------------------------------------------------------------- note fields { */
 
 #define KLB_NOTE										"note"
 
@@ -376,6 +378,6 @@
 #define KLB_NOTE_BACKGROUND_COLOR						"background-color"
 #define KLB_NOTE_FOREGROUND_COLOR						"foreground-color"
 
-// --------------------------------------------------------------- note fields }
+/* --------------------------------------------------------------- note fields } */
 
 #endif /* KOLAB_CONSTANTS_H_ */
