@@ -134,20 +134,21 @@ datetime_to_string (const time_t *time, gchar *date_string)
 xmlDocPtr
 util_get_kolab_xml_part(const Kolab_conv_mail *klb_mail, GList **other_parts, GError **error)
 {
-	// check input paramters
+	xmlDocPtr doc = NULL;
+	guint i;
+	
+	/* check input paramters */
 	if (klb_mail == NULL) {
 		g_set_error(error, KOLABCONV_ERROR_READ_KOLAB,
 				KOLABCONV_ERROR_READ_KOLAB_INPUT_IS_NULL,
 				"kolab mail struct must not be null");
 		return NULL;
 	}
-	// iterate over mail parts, search kolab xml part, parse and return it
-	xmlDocPtr doc = NULL;
-	guint i;
+	/* iterate over mail parts, search kolab xml part, parse and return it */
 	for (i = 0; i < klb_mail->length; i++) {
 		Kolab_conv_mail_part *mail_part = klb_mail->mail_parts + i;
 		if (g_str_has_prefix(mail_part->mime_type, KOLAB_MESSAGE_MIMETYPE_PREFIX)) {
-			// found kolab xml part => parse it in memory
+			/* found kolab xml part => parse it in memory */
 			doc = xmlReadMemory (mail_part->data, (int) mail_part->length, NULL, NULL, 0);
 			if (doc == NULL) {
 				g_set_error(error, KOLABCONV_ERROR_READ_KOLAB,
@@ -155,10 +156,10 @@ util_get_kolab_xml_part(const Kolab_conv_mail *klb_mail, GList **other_parts, GE
 						"xml parser returned null for data part %d", i);
 				return NULL;
 			}
-		} else // part must be cloned here because it will be freed when converting from internal
+		} else /* part must be cloned here because it will be freed when converting from internal */
 			*other_parts = g_list_append(*other_parts, clone_kolab_conv_mail_part(mail_part));
 	}
-	if (doc == NULL) // no kolab xml part could be found
+	if (doc == NULL) /* no kolab xml part could be found */
 		g_set_error(error, KOLABCONV_ERROR_READ_KOLAB,
 			KOLABCONV_ERROR_READ_KOLAB_MISSING_XML_PART,
 			"kolab mail struct has no kolab xml data part");
@@ -176,7 +177,7 @@ util_get_kolab_xml_part(const Kolab_conv_mail *klb_mail, GList **other_parts, GE
 gchar*
 xml_get_node_text(xmlNodePtr node)
 {
-	// get text content form node
+	/* get text content form node */
 	gchar* value = NULL;
 	xmlNodePtr n;
 	for (n = node->children; n != NULL; n = n->next) {
@@ -185,8 +186,9 @@ xml_get_node_text(xmlNodePtr node)
 		else
 			log_warn("tag %s is not a simple text element as expected", node->name);
 	}
-	// if node has no text content set value to empty string to be able to
-	// differentiate between an existing and a not existing element
+	/* if node has no text content set value to empty string to be able to
+	 * differentiate between an existing and a not existing element
+	 */
 	return value == NULL ? "" : value;
 }
 
@@ -208,16 +210,17 @@ xml_get_boolean(xmlNodePtr node)
 gboolean
 handle_element_GList_String (gchar* list_name, gchar* element_name, GList **store_string_list, xmlNodePtr node)
 {
+	xmlNodePtr element_node = NULL; /* used in for loop */
+
 	if (g_strcmp0 ((gchar *) node->name, list_name) != 0)
 		return FALSE;
 
-	xmlNodePtr element_node; // used in for loop
 	for (element_node = node->children; element_node != NULL; element_node = element_node->next) {
 		if (element_node->type == XML_ELEMENT_NODE) {
 			if (g_strcmp0 ((gchar *) element_node->name, element_name) == 0) {
 				GString *value = g_string_new(xml_get_node_text(element_node));
 				*store_string_list = g_list_append(*store_string_list, value);
-				g_debug ("**** handle_element_GList_String() node: %s - value: '%s'", element_node->name, value);
+				g_debug ("**** handle_element_GList_String() node: %s - value: '%s'", element_node->name, value->str);
 			}
 		}
 	}
@@ -240,14 +243,15 @@ handle_element_chars (gchar* name, gchar **store, xmlNodePtr node)
 	if (g_strcmp0 ((gchar *) node->name, name) != 0)
 		return FALSE;
 
-	// GString store is expected NULL. If not, maybe the element
-	// unexpectedly occurs multiple times => warn and reassign
+	/* GString store is expected NULL. If not, maybe the element
+	 * unexpectedly occurs multiple times => warn and reassign
+	 */
 	if (*store != NULL) {
 		log_warn("multiple assignment of string variable");
 		g_free(*store);
 	}
 
-	// create gchar with the text content of the node
+	/* create gchar with the text content of the node */
 	*store = g_strdup_printf("%s", xml_get_node_text(node));
 	return TRUE;
 }
@@ -269,8 +273,9 @@ handle_element_string (gchar* name, GString **store, xmlNodePtr node)
 	if (!handle_element_chars (name, &value, node))
 		return FALSE;
 
-	// GString store is expected NULL. If not, maybe the element
-	// unexpectedly occurs multiple times => warn and reassign
+	/* GString store is expected NULL. If not, maybe the element
+	 * unexpectedly occurs multiple times => warn and reassign
+	 */
 	if (*store != NULL) {
 		log_warn("multiple assignment of string variable");
 		g_string_free(*store, TRUE);
@@ -301,48 +306,52 @@ handle_element_string (gchar* name, GString **store, xmlNodePtr node)
 gboolean
 handle_element_integer (gchar* name, gint *store, xmlNodePtr node)
 {
+	gchar *value = NULL;
+	gchar *p = NULL;
+	
 	if (g_strcmp0 ((gchar *) node->name, name) != 0)
 		return FALSE;
 
-	gchar *value = xml_get_node_text(node);
+	value = xml_get_node_text(node);
 	g_debug ("**** handle_element_integer() node: %s - value: %s", node->name, value);
-	gchar *p;
 	errno = 0;
 	*store = strtol(value, &p, 10);
 	if (errno != 0 || *p != 0 || p == value)
-		log_warn("illegal integer value in element %s", name); //TODO: error handling
+		log_warn("illegal integer value in element %s", name); /* TODO: error handling */
 	return TRUE;
 }
 
 gboolean
 handle_element_double (gchar* name, gdouble *store, xmlNodePtr node)
 {
+	gchar *value = NULL;
+	gchar *p = NULL;
+	
 	if (g_strcmp0 ((gchar *) node->name, name) != 0)
 		return FALSE;
 
-	gchar *value = xml_get_node_text(node);
+	value = xml_get_node_text(node);
 	g_debug ("**** handle_element_double() node: %s - value: %s", node->name, value);
-	gchar *p;
 	errno = 0;
 	*store = strtod(value, &p);
 	if (errno != 0 || *p != 0 || p == value)
-		log_warn("illegal double value in element %s", name); //TODO error handling
+		log_warn("illegal double value in element %s", name); /* TODO error handling */
 	return TRUE;
 }
 
 gboolean
 handle_element_date (gchar* name, GDate** store, xmlNodePtr node)
 {
+	GDate* date = NULL;
+	gchar* value = NULL;
+	gchar** date_tokens = NULL;
+	gint day = 0, month = 0, year = 0;
+
 	if (g_strcmp0 ((gchar *) node->name, name) != 0)
 		return FALSE;
 
-	GDate* date;
-
-	gchar* value = xml_get_node_text(node);
-
-	gchar** date_tokens = g_strsplit (value, "-", -1);
-
-	gint day = 0, month = 0, year = 0;
+	value = xml_get_node_text(node);
+	date_tokens = g_strsplit (value, "-", -1);
 
 	year = strtol(date_tokens[0], NULL, 10);
 	month = strtol(date_tokens[1], NULL, 10);
@@ -357,33 +366,35 @@ handle_element_date (gchar* name, GDate** store, xmlNodePtr node)
 	return TRUE;
 }
 
-
-
 gboolean
 handle_element_date_or_datetime (gchar* name, Date_or_datetime** store, xmlNodePtr node)
 {
+	gchar *value = NULL;
+	
 	if (g_strcmp0 ((gchar *) node->name, name) != 0)
 		return FALSE;
 
-	// store is expected NULL. If not, maybe the element
-	// unexpectedly occurs multiple times => warn and reassign
+	/* store is expected NULL. If not, maybe the element
+	 * unexpectedly occurs multiple times => warn and reassign
+	 */
 	if (*store != NULL)
 		log_warn("multiple assignment of string variable");
 	else
 		*store = g_new0(Date_or_datetime, 1);
 
-	gchar *value = xml_get_node_text(node);
+	value = xml_get_node_text(node);
 
 	g_debug ("**** handle_element_date_or_datetime() node: %s - value: '%s'", node->name, value);
 
 	if (strlen (value) < 12) {
-		//Populate only date
+		gint day = 0, month = 0, year = 0;
+
+		/* Populate only date */
 		gchar** date_tokens = g_strsplit (value, "-", -1);
 		if (*date_tokens == NULL) {
 			*store = NULL;
 			return TRUE;
 		}
-		gint day = 0, month = 0, year = 0;
 
 		year = strtol(date_tokens[0], NULL, 10);
 		month = strtol(date_tokens[1], NULL, 10);
@@ -395,14 +406,16 @@ handle_element_date_or_datetime (gchar* name, Date_or_datetime** store, xmlNodeP
 		g_strfreev(date_tokens);
 
 	} else {
-		// convert string to 'struct tm'
-		if (value[10] == 'T') // remove 'T' in iso timestamp if neccessary
+		struct tm t;
+		time_t tt;
+		
+		/* convert string to 'struct tm' */
+		if (value[10] == 'T') /* remove 'T' in iso timestamp if neccessary */
 		        value[10] = ' ';
 
-		struct tm t;
-		strptime(value, "%Y-%m-%d %H:%M:%S", &t); // string to tm
+		strptime(value, "%Y-%m-%d %H:%M:%S", &t); /* string to tm */
 
-		time_t tt = time_gm(&t); // tm to seconds
+		tt = time_gm(&t); /* tm to seconds */
 
 		g_debug ("**** handle_element_date_or_datetime() tt: '%lu'", tt);
 
@@ -417,32 +430,36 @@ handle_element_date_or_datetime (gchar* name, Date_or_datetime** store, xmlNodeP
 
 
 gboolean
-handle_element_datetime (gchar* name, time_t** store, xmlNodePtr node) {
+handle_element_datetime (gchar* name, time_t** store, xmlNodePtr node)
+{
+	gchar *value = NULL;
+	struct tm t;
+	
 	if (g_strcmp0 ((gchar *) node->name, name) != 0)
 		return FALSE;
 
-	// store is expected NULL. If not, maybe the element
-	// unexpectedly occurs multiple times => warn and reassign
+	/* store is expected NULL. If not, maybe the element
+	 * unexpectedly occurs multiple times => warn and reassign
+	 */
 	if (*store != NULL)
 		log_warn("multiple assignment of string variable");
 	else
 		*store = g_new0(time_t, 1);
 
-	gchar *value = xml_get_node_text(node);
+	value = xml_get_node_text(node);
 
-	// convert string to 'struct tm'
-	if (value[10] == 'T') // remove 'T' in iso timestamp if neccessary
+	/* convert string to 'struct tm' */
+	if (value[10] == 'T') /* remove 'T' in iso timestamp if neccessary */
 		value[10] = ' ';
 
-	struct tm t;
-	strptime(value, "%Y-%m-%d %H:%M:%S", &t); // string to tm
+	strptime(value, "%Y-%m-%d %H:%M:%S", &t); /* string to tm */
 
-	**store = time_gm(&t); // tm to seconds
+	**store = time_gm(&t); /* tm to seconds */
 
 	return TRUE;
 }
 
-// XML-TREE manipulation functions
+/* XML-TREE manipulation functions */
 
 /*
  * converts a GList of strings to xml nodes with the same name below one node
@@ -465,16 +482,17 @@ void convert_GList_String_to_xmlNodes (GList *string_list, char* node_name, xmlN
 gchar*
 convert_xmlNode_to_String (const xmlNodePtr node)
 {
-	xmlDocPtr doc;
-	xmlChar *xmlbuff;
+	xmlDocPtr doc = NULL;
+	xmlChar *xmlbuff = NULL;
 	gint buffersize;
+	gchar *xmlStr = NULL;
 
 	doc = xmlNewDoc(BAD_CAST "1.0");
 
 	xmlDocSetRootElement (doc, xmlCopyNode (node, 1));
 
 	xmlDocDumpFormatMemoryEnc (doc, &xmlbuff, &buffersize, "UTF-8", 1);
-	gchar *xmlStr = g_strdup((gchar*) xmlbuff);
+	xmlStr = g_strdup((gchar*) xmlbuff);
 
 	xmlFree (xmlbuff);
 	xmlFreeDoc (doc);
@@ -510,12 +528,13 @@ printKolabXmlMailPartArray(const GList* kolabconvMailArray)
 {
 
 	const GList *iterator = kolabconvMailArray;
+	gint i=1;
 
 	log_debug("\n*********************Printing kolabXmlmailArray:***************************");
-	gint i=1;
+
 	while(iterator != NULL){
 		log_debug("\n\nFile no. %d", i);
-		//log_debug("\n\tOrder: %d", ((Kolab_conv_mail_part*)iterator->data)->order  );
+		/* log_debug("\n\tOrder: %d", ((Kolab_conv_mail_part*)iterator->data)->order  ); */
 		log_debug("\n\tMimeType: %s", ((Kolab_conv_mail_part*)iterator->data)->mime_type  );
 		log_debug("\n\tName: %s", ((Kolab_conv_mail_part*)iterator->data)->name  );
 		log_debug("\n\tLength: %d", ((Kolab_conv_mail_part*)iterator->data)->length  );
@@ -533,6 +552,7 @@ printKolabXmlMailPartArray(const GList* kolabconvMailArray)
 void
 printXMLTree (xmlNodePtr node, int depth)
 {
+	xmlNodePtr children;
 	gint i = 0;
 
 	log_debug ("\n");
@@ -544,12 +564,9 @@ printXMLTree (xmlNodePtr node, int depth)
 	if (node->content != NULL)
 		log_debug (" & Node-content: %s", node->content);
 
-	xmlNodePtr children;
-
 	for (children = node->children; children != NULL; children = children->next) {
 		printXMLTree (children, depth + 1);
 	}
-
 }
 
 
@@ -558,7 +575,7 @@ printXMLTree (xmlNodePtr node, int depth)
 xmlNodePtr
 add_child_node (xmlNodePtr root_node, gchar *child_name, gchar *child_contents)
 {
-	// xmlNewTextChild() implicitly converts reserved XML characters (e.g. '&') to entities
+	/* xmlNewTextChild() implicitly converts reserved XML characters (e.g. '&') to entities */
 	return xmlNewTextChild (root_node, NULL, BAD_CAST child_name, BAD_CAST child_contents);
 }
 
@@ -569,9 +586,11 @@ add_property (xmlNodePtr node, gchar *propertyName, gchar *propertyContents)
 }
 
 
-/** This formats a UTC offset as "+HHMM" or "+HHMMSS".
- buffer should have space for 8 characters. */
-// copied form libical/src/libical/icaltimezone.c
+/**
+ * This formats a UTC offset as "+HHMM" or "+HHMMSS".
+ * buffer should have space for 8 characters.
+ * (copied form libical/src/libical/icaltimezone.c)
+ */
 void
 format_utc_offset (gint utc_offset, gchar *buffer)
 {
@@ -649,4 +668,3 @@ gint priority_xkcal_to_k(gint xkcal_prio) {
 		default: return 3;
 	}
 }
-
