@@ -31,9 +31,9 @@
  * The related header file is: k-abstract.h
  */
 
-#include "priv-kolab.h" // public part of this file
+#include "priv-kolab.h"		/* public part of this file */
 #include "../util.h"
-#include <libxml/tree.h>	// XML parsing
+#include <libxml/tree.h>	/* XML parsing */
 
 /*
  * prototypes for static functions
@@ -77,14 +77,14 @@ conv_incidence_k_to_i(I_incidence *i_incidence, xmlNodePtr node, GError **error)
 	else if (*error != NULL)
 		return FALSE;
 
-	return	handle_element_string(KLB_INC_SUMMARY, &i_incidence->summary, node) ||				// summary
-		handle_element_string(KLB_INC_LOCATION, &i_incidence->location, node) ||			// location									// creator
-		handle_incidence_organizer(i_incidence, node) ||						// organizer
-		handle_element_date_or_datetime(KLB_INC_START_DATE, &i_incidence->start_date, node) ||		// start-date
-		handle_incidence_alarm(i_incidence, node) ||							// alarm
-		handle_incidence_advanced_alarm(i_incidence, node) ||						// advanced_alarm
-		handle_incidence_recurrence(i_incidence, node) ||						// recurrence
-		handle_incidence_attendee(i_incidence, node);							// attendee
+	return	handle_element_string(KLB_INC_SUMMARY, &i_incidence->summary, node) ||				/* summary */
+		handle_element_string(KLB_INC_LOCATION, &i_incidence->location, node) ||			/* location */
+		handle_incidence_organizer(i_incidence, node) ||						/* organizer */
+		handle_element_date_or_datetime(KLB_INC_START_DATE, &i_incidence->start_date, node) ||		/* start-date */
+		handle_incidence_alarm(i_incidence, node) ||							/* alarm */
+		handle_incidence_advanced_alarm(i_incidence, node) ||						/* advanced_alarm */
+		handle_incidence_recurrence(i_incidence, node) ||						/* recurrence */
+		handle_incidence_attendee(i_incidence, node);							/* attendee */
 }
 
 
@@ -241,13 +241,13 @@ handle_incidence_alarm(I_incidence *incidence, xmlNodePtr node)
 	if (strcmp ((gchar *) node->name, KLB_INC_ALARM) != 0)
 			return FALSE;
 
-	if (node->type == XML_ELEMENT_NODE) {															// Alarm_type type
+	if (node->type == XML_ELEMENT_NODE) { /* Alarm_type type */
 		Alarm *adv_alarm = new_alarm(alarm_type_k_to_i("KLBX_INC_ADV_ALARM_TYPE_DISPLAY_TEXT"));
 
-		// start_offset
+		/* start_offset */
 		handle_element_integer(KLB_INC_ALARM, &adv_alarm->start_offset, node);
 
-		// add advanced_alarm to list
+		/* add advanced_alarm to list */
 		incidence->advanced_alarm = g_list_append(incidence->advanced_alarm, (gpointer) adv_alarm);
 	}
 	return TRUE;
@@ -264,23 +264,24 @@ handle_incidence_alarm(I_incidence *incidence, xmlNodePtr node)
 static gboolean
 handle_incidence_advanced_alarm (I_incidence *incidence, xmlNodePtr node)
 {
+	xmlNodePtr alarm_node = NULL; /* used in for loop */
+
 	if (strcmp ((gchar *) node->name, KLBX_INC_ADV_ALARM) != 0)
 		return FALSE;
 
-	xmlNodePtr alarm_node; // used in for loop
 	for (alarm_node = node->children; alarm_node != NULL; alarm_node = alarm_node->next) {
 		if (alarm_node->type == XML_ELEMENT_NODE) {
 
 			if (strcmp ((gchar *) alarm_node->name, KLB_INC_ALARM) == 0) {
+				xmlNodePtr alarm_attribute = NULL; /* used in for loop */
 				gchar *type = (gchar *) xmlGetProp (alarm_node, (xmlChar *) KLBX_INC_ADV_ALARM_TYPE);
 				Alarm *adv_alarm = new_alarm(alarm_type_k_to_i(type));
 				g_free(type);
 
-				xmlNodePtr alarm_attribute; // used in for loop
 				for (alarm_attribute = alarm_node->children; alarm_attribute != NULL; alarm_attribute = alarm_attribute->next) {
 
 					if (alarm_attribute->type == XML_ELEMENT_NODE) {
-						// handle advanced alarm type dependent attributes
+						/* handle advanced alarm type dependent attributes */
 						gboolean handled = FALSE;
 						if (adv_alarm->type == I_ALARM_TYPE_DISPLAY) {
 							handled  = handle_element_string(KLBX_INC_ADV_ALARM_TYPE_DISPLAY_TEXT, &adv_alarm->display_text, alarm_attribute);
@@ -296,14 +297,14 @@ handle_incidence_advanced_alarm (I_incidence *incidence, xmlNodePtr node)
 							handled |= handle_element_GList_String(KLBX_INC_ADV_ALARM_TYPE_EMAIL_ATTACHMENTS, KLBX_INC_ADV_ALARM_TYPE_EMAIL_ATTACHMENTS_ATT, &adv_alarm->email_param->attachments, alarm_attribute);
 						}
 
-						// handle advanced alarm common attributes
-						if (strcmp ((gchar *) alarm_attribute->name, KLBX_INC_ADV_ALARM_START_OFFSET) == 0) {						// start_offset
+						/* handle advanced alarm common attributes */
+						if (strcmp ((gchar *) alarm_attribute->name, KLBX_INC_ADV_ALARM_START_OFFSET) == 0) {					/* start_offset */
 							handle_element_integer(KLBX_INC_ADV_ALARM_START_OFFSET, &adv_alarm->start_offset, alarm_attribute);
-						} else if (strcmp ((gchar *) alarm_attribute->name, KLBX_INC_ADV_ALARM_END_OFFSET) == 0) {				// end_offset
+						} else if (strcmp ((gchar *) alarm_attribute->name, KLBX_INC_ADV_ALARM_END_OFFSET) == 0) {				/* end_offset */
 							handle_element_integer(KLBX_INC_ADV_ALARM_END_OFFSET, &adv_alarm->end_offset, alarm_attribute);
-						} else if (strcmp ((gchar *) alarm_attribute->name, KLBX_INC_ADV_ALARM_REPEAT_COUNT) == 0) {				// repeat_count
+						} else if (strcmp ((gchar *) alarm_attribute->name, KLBX_INC_ADV_ALARM_REPEAT_COUNT) == 0) {				/* repeat_count */
 							handle_element_integer(KLBX_INC_ADV_ALARM_REPEAT_COUNT, &adv_alarm->repeat_count, alarm_attribute);
-						} else if (strcmp ((gchar *) alarm_attribute->name, KLBX_INC_ADV_ALARM_REPEAT_INTERVAL) == 0) {			// repeat_interval
+						} else if (strcmp ((gchar *) alarm_attribute->name, KLBX_INC_ADV_ALARM_REPEAT_INTERVAL) == 0) {				/* repeat_interval */
 							handle_element_integer(KLBX_INC_ADV_ALARM_REPEAT_INTERVAL, &adv_alarm->repeat_interval, alarm_attribute);
 						} else if (strcmp ((gchar *) alarm_attribute->name, KLBX_INC_ADV_ALARM_TYPE_EMAIL_ADDRESSES) == 0) {
 						} else if (!handled)
@@ -311,7 +312,7 @@ handle_incidence_advanced_alarm (I_incidence *incidence, xmlNodePtr node)
 					}
 
 				}
-				// add advanced_alarm to list
+				/* add advanced_alarm to list */
 				incidence->advanced_alarm = g_list_append(incidence->advanced_alarm, (gpointer) adv_alarm);
 			}
 		}
@@ -376,10 +377,12 @@ handle_incidence_recurrence_cycle (xmlNodePtr node)
 static gboolean
 handle_incidence_recurrence_weekdays (guint *weekdays, xmlNodePtr node)
 {
+	gchar *value = NULL;
+	
 	if (strcmp ((gchar *) node->name, KLB_INC_RCR_DAY) != 0)
 		return FALSE;
 
-	gchar *value = xml_get_node_text(node);
+	value = xml_get_node_text(node);
 	*weekdays |= weekday_k_to_i(value);
 	return TRUE;
 }
@@ -395,10 +398,12 @@ handle_incidence_recurrence_weekdays (guint *weekdays, xmlNodePtr node)
 static gboolean
 handle_incidence_recurrence_month (Month *month, xmlNodePtr node)
 {
+	gchar *value = NULL;
+	
 	if (strcmp ((gchar *) node->name, KLB_INC_RCR_MONTH) != 0)
 		return FALSE;
 
-	gchar *value = xml_get_node_text(node);
+	value = xml_get_node_text(node);
 	*month = month_k_to_i(value);
 	return TRUE;
 }
@@ -414,11 +419,14 @@ handle_incidence_recurrence_month (Month *month, xmlNodePtr node)
 static gboolean
 handle_incidence_recurrence_exclusion (GList **exclusion_list, xmlNodePtr node)
 {
+	gchar *value = NULL;
+	GDate *date = NULL;
+	
 	if (strcmp ((gchar *) node->name, KLB_INC_RCR_EXCLUSION) != 0)
 		return FALSE;
 
-	gchar *value = xml_get_node_text(node);
-	GDate *date = string_to_g_date(value);
+	value = xml_get_node_text(node);
+	date = string_to_g_date(value);
 	*exclusion_list = g_list_append(*exclusion_list, date);
 	return TRUE;
 }
@@ -437,11 +445,13 @@ handle_incidence_recurrence_exclusion (GList **exclusion_list, xmlNodePtr node)
 static gboolean
 handle_incidence_recurrence_range (GDate **rdate, gint **rnumber, xmlNodePtr node)
 {
+	gchar *rtype = NULL;
+	
 	if (strcmp ((gchar *) node->name, KLB_INC_RCR_RANGE) != 0)
 		return FALSE;
 
 
-	gchar *rtype = (gchar *) xmlGetProp (node, (xmlChar *) KLB_INC_RCR_RANGETYPE);
+	rtype = (gchar *) xmlGetProp (node, (xmlChar *) KLB_INC_RCR_RANGETYPE);
 	if (rtype != NULL) {
 
 		gchar *value = xml_get_node_text(node);
@@ -481,11 +491,14 @@ handle_incidence_recurrence_range (GDate **rdate, gint **rnumber, xmlNodePtr nod
 static gboolean
 handle_incidence_recurrence (I_incidence *incidence, xmlNodePtr node)
 {
+	xmlNodePtr n = NULL; /* used in for loop */
+
 	if (strcmp ((gchar*) node->name, KLB_INC_RECURRENCE) != 0)
 		return FALSE;
 
-	// recurrence struct ptr is expected NULL. If not, maybe the element
-	// unexpectedly occurs multiple times => warn and reassign
+	/* recurrence struct ptr is expected NULL. If not, maybe the element
+	 * unexpectedly occurs multiple times => warn and reassign
+	 */
 	if (incidence->recurrence != NULL) {
 		log_warn("multiple assignment of recurrence");
 		g_free(incidence->recurrence);
@@ -494,8 +507,7 @@ handle_incidence_recurrence (I_incidence *incidence, xmlNodePtr node)
 	incidence->recurrence = new_recurrence ();
 	incidence->recurrence->recurrence_cycle = handle_incidence_recurrence_cycle(node);
 
-	// iterate over all child elements of node an process them
-	xmlNodePtr n; // used in for loop
+	/* iterate over all child elements of node an process them */
 	for (n = node->children; n != NULL; n = n->next) {
 		if (n->type == XML_ELEMENT_NODE) {
 			if (handle_incidence_recurrence_weekdays((guint *) &incidence->recurrence->weekdays, n)
@@ -520,12 +532,14 @@ handle_incidence_recurrence (I_incidence *incidence, xmlNodePtr node)
 static gboolean
 handle_incidence_attendee(I_incidence *incidence, xmlNodePtr node)
 {
+	Attendee *attendee = NULL;
+	xmlNodePtr n = NULL; /* used in for loop */
+	
 	if (strcmp ((gchar*) node->name, KLB_INC_ATTENDEE) != 0)
 		return FALSE;
 
-	Attendee *attendee = g_new0(Attendee, 1);
+	attendee = g_new0(Attendee, 1);
 
-	xmlNodePtr n; // used in for loop
 	for (n = node->children; n != NULL; n = n->next) {
 		if (n->type == XML_ELEMENT_NODE) {
 			if (strcmp ((gchar *) n->name, KLB_INC_DISPLAY_NAME) == 0) {
@@ -553,7 +567,7 @@ handle_incidence_attendee(I_incidence *incidence, xmlNodePtr node)
 		}
 	}
 	xmlFree(n);
-	// add attendee to list
+	/* add attendee to list */
 	incidence->attendee = g_list_append(incidence->attendee, (gpointer) attendee);
 
 	return TRUE;
@@ -567,10 +581,11 @@ handle_incidence_attendee(I_incidence *incidence, xmlNodePtr node)
 static gboolean
 handle_incidence_organizer (I_incidence *i_incidence, xmlNodePtr node)
 {
+	xmlNodePtr n = NULL; /* used in for loop */
+
 	if (strcmp ((gchar*) node->name, KLB_INC_ORGANIZER) != 0)
 		return FALSE;
-	// iterate over all child elements of node an process them
-	xmlNodePtr n; // used in for loop
+	/* iterate over all child elements of node an process them */
 	for (n = node->children; n != NULL; n = n->next) {
 		if (n->type == XML_ELEMENT_NODE) {
 			if (handle_element_string(KLB_INC_DISPLAY_NAME, &i_incidence->organizer_display_name, n)
@@ -583,5 +598,3 @@ handle_incidence_organizer (I_incidence *i_incidence, xmlNodePtr node)
 	xmlFree(n);
 	return TRUE;
 }
-
-
