@@ -34,7 +34,7 @@
  */
 typedef struct {
 	I_common 	*common;
-	GString 	*summary;	//default empty
+	GString 	*summary;	/* default empty */
 } I_note;
 
 /*
