@@ -288,7 +288,7 @@ validate_evolution_contact_3 (const I_contact *icontact, gint stage)
 	/*
 	 * Phone Numbers
 	 */
-	assert_phone_in_list (icontact->phone_numbers, "Weiteres Fax", ICONTACT_PHONE_BUSINESS_FAX); // Kolab does not have a type 'Other Fax' so it is mapped to business fax
+	assert_phone_in_list (icontact->phone_numbers, "Weiteres Fax", ICONTACT_PHONE_BUSINESS_FAX); /* Kolab does not have a type 'Other Fax' so it is mapped to business fax */
 	assert_phone_in_list (icontact->phone_numbers, "Weiteres Tel", ICONTACT_PHONE_OTHER);
 	assert_phone_in_list (icontact->phone_numbers, "Fax privat", ICONTACT_PHONE_HOME_FAX);
 	assert_phone_in_list (icontact->phone_numbers, "Autotelefon", ICONTACT_PHONE_CAR);
