@@ -42,11 +42,11 @@ validate_evolution_event_1(const I_event *ievent, gint stage)
 			"2010-08-25 14:40:07", stage);
 
 	validate_iincidence(ievent->incidence,
-			"event_e1", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-08-27 14:30:00", // startdate
+			"event_e1", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-08-27 14:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -77,11 +77,11 @@ validate_evolution_event_2(const I_event *ievent, gint stage)
 			ICOMMON_SENSITIVITY_PUBLIC, "2010-08-25 14:42:20", "2010-08-25 14:42:20", stage);
 
 	validate_iincidence(ievent->incidence,
-			"event_e2", // summary
-			"Ort", // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-08-27 14:30:00", // startdate
+			"event_e2", /* summary */
+			"Ort", /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-08-27 14:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -104,11 +104,11 @@ validate_evolution_event_3(const I_event *ievent, gint stage)
 			ICOMMON_SENSITIVITY_PUBLIC, "2010-08-25 14:45:51", "2010-08-25 14:45:51", stage);
 
 	validate_iincidence(ievent->incidence,
-			"event_e3", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-08-27 14:30:00", // startdate
+			"event_e3", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-08-27 14:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -129,11 +129,11 @@ validate_evolution_event_4(const I_event *ievent, gint stage)
 			ICOMMON_SENSITIVITY_PUBLIC, "2010-08-25 14:48:07", "2010-08-25 14:48:07", stage);
 
 	validate_iincidence(ievent->incidence,
-			"event_e4", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-08-27 14:30:00", // startdate
+			"event_e4", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-08-27 14:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -149,17 +149,17 @@ validate_evolution_event_5(const I_event *ievent, gint stage)
 
 	assert_Alarm_in_list(
 			ievent->incidence->advanced_alarm,
-			I_ALARM_TYPE_DISPLAY,	// type
-			-15,				// start_offset
-			0,					// end_offset
-			2,					// repeat_count
-			5,					// repeat_interval
-			NULL,				// display_text
-			NULL,				// audio_file
-			NULL,				// procParam_program
-			NULL,				// procParam_arguments
-			NULL,				// emailParam_subject
-			NULL);				// emailParam_mailText
+			I_ALARM_TYPE_DISPLAY,	/* type */
+			-15,			/* start_offset		*/
+			0,			/* end_offset		*/
+			2,			/* repeat_count		*/
+			5,			/* repeat_interval	*/
+			NULL,			/* display_text		*/
+			NULL,			/* audio_file		*/
+			NULL,			/* procParam_program	*/
+			NULL,			/* procParam_arguments	*/
+			NULL,			/* emailParam_subject	*/
+			NULL);			/* emailParam_mailText	*/
 }
 
 void
@@ -169,17 +169,17 @@ validate_evolution_event_6(const I_event *ievent, gint stage)
 
 	assert_Alarm_in_list(
 			ievent->incidence->advanced_alarm,
-			I_ALARM_TYPE_AUDIO,	// type
-			1020,				// start_offset
-			0,					// end_offset
-			3,					// repeat_count
-			360,				// repeat_interval
-			NULL,				// display_text
-			NULL,				// audio_file
-			NULL,				// procParam_program
-			NULL,				// procParam_arguments
-			NULL,				// emailParam_subject
-			NULL);				// emailParam_mailText
+			I_ALARM_TYPE_AUDIO,	/* type			*/
+			1020,			/* start_offset		*/
+			0,			/* end_offset		*/
+			3,			/* repeat_count		*/
+			360,			/* repeat_interval	*/
+			NULL,			/* display_text		*/
+			NULL,			/* audio_file		*/
+			NULL,			/* procParam_program	*/
+			NULL,			/* procParam_arguments	*/
+			NULL,			/* emailParam_subject	*/
+			NULL);			/* emailParam_mailText	*/
 }
 
 void
@@ -189,17 +189,17 @@ validate_evolution_event_7(const I_event *ievent, gint stage)
 
 	assert_Alarm_in_list(
 			ievent->incidence->advanced_alarm,
-			I_ALARM_TYPE_AUDIO,	// type
-			0,					// start_offset
-			18720,				// end_offset
-			0,					// repeat_count
-			0,					// repeat_interval
-			NULL,				// display_text
-			"file:///usr/share/sounds/gnome/default/alerts/bark.ogg",				// audio_file
-			NULL,				// procParam_program
-			NULL,				// procParam_arguments
-			NULL,				// emailParam_subject
-			NULL);				// emailParam_mailText
+			I_ALARM_TYPE_AUDIO,	/* type			*/
+			0,			/* start_offset		*/
+			18720,			/* end_offset		*/
+			0,			/* repeat_count		*/
+			0,			/* repeat_interval	*/
+			NULL,			/* display_text		*/
+			"file:///usr/share/sounds/gnome/default/alerts/bark.ogg", /* audio_file */
+			NULL,			/* procParam_program	*/
+			NULL,			/* procParam_arguments	*/
+			NULL,			/* emailParam_subject	*/
+			NULL);			/* emailParam_mailText	*/
 }
 
 void
@@ -209,17 +209,17 @@ validate_evolution_event_8(const I_event *ievent, gint stage)
 
 	assert_Alarm_in_list(
 				ievent->incidence->advanced_alarm,
-				I_ALARM_TYPE_PROCEDURE,	// type
-				0,					// start_offset
-				-15840,				// end_offset
-				3,					// repeat_count
-				120,				// repeat_interval
-				NULL,				// display_text
-				NULL,				// audio_file
-				"/usr/bin/xmessage",	// procParam_program
-				"Alert!",				// procParam_arguments
-				NULL,				// emailParam_subject
-				NULL);				// emailParam_mailText
+				I_ALARM_TYPE_PROCEDURE,	/* type			*/
+				0,			/* start_offset		*/
+				-15840,			/* end_offset		*/
+				3,			/* repeat_count		*/
+				120,			/* repeat_interval	*/
+				NULL,			/* display_text		*/
+				NULL,			/* audio_file		*/
+				"/usr/bin/xmessage",	/* procParam_program	*/
+				"Alert!",		/* procParam_arguments	*/
+				NULL,			/* emailParam_subject	*/
+				NULL);			/* emailParam_mailText	*/
 }
 
 void
@@ -230,11 +230,11 @@ validate_evolution_event_9(const I_event *ievent, gint stage)
 	g_assert(SHOW_TIME_AS_FREE == ievent->show_time_as);
 
 	validate_iincidence(ievent->incidence,
-			"event_e9", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-08-27", // startdate
+			"event_e9", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-08-27", /* startdate */
 			stage);
 
 	assert_equal_gdate("2010-08-27", ievent->end_date->date);
@@ -255,6 +255,8 @@ validate_evolution_event_10(const I_event *ievent, gint stage)
 void
 validate_evolution_event_11(const I_event *ievent, gint stage)
 {
+	gint rdate[3] = {10,9,2010};
+
 	log_bitmask(stage);
 
 	g_assert(ievent != NULL);
@@ -265,7 +267,6 @@ validate_evolution_event_11(const I_event *ievent, gint stage)
 			NULL, NULL, ICOMMON_SENSITIVITY_PUBLIC,
 			NULL, "2010-08-25 15:11:22", stage);
 
-	gint rdate[3] = {10,9,2010};
 	validate_recurrence(ievent->incidence->recurrence,
 			I_REC_CYCLE_DAILY, 2, 0, rdate, 0, 0, 0);
 }
@@ -307,6 +308,8 @@ validate_evolution_event_13(const I_event *ievent, gint stage)
 void
 validate_evolution_event_14(const I_event *ievent, gint stage)
 {
+	gint rdate[3] = {27,9,2010};
+
 	log_bitmask(stage);
 
 	g_assert(ievent != NULL);
@@ -317,7 +320,6 @@ validate_evolution_event_14(const I_event *ievent, gint stage)
 			NULL, NULL, ICOMMON_SENSITIVITY_PUBLIC,
 			NULL, "2010-08-25 15:19:22", stage);
 
-	gint rdate[3] = {27,9,2010};
 	validate_recurrence(ievent->incidence->recurrence,
 			I_REC_CYCLE_WEEKLY, 2, 0, rdate, I_COMMON_MONDAY | I_COMMON_TUESDAY, 0, 0);
 }
@@ -391,6 +393,8 @@ validate_evolution_event_17(const I_event *ievent, gint stage)
 void
 validate_evolution_event_18(const I_event *ievent, gint stage)
 {
+	gint rdate[3] = {23,11,2010};
+
 	log_bitmask(stage);
 
 	/*
@@ -416,7 +420,6 @@ validate_evolution_event_18(const I_event *ievent, gint stage)
 			NULL, NULL, ICOMMON_SENSITIVITY_PUBLIC,
 			NULL, "2010-08-25 15:28:25", stage);
 
-	gint rdate[3] = {23,11,2010};
 	validate_recurrence(ievent->incidence->recurrence,
 			I_REC_CYCLE_MONTHLY_WEEKDAY, 1, 0, rdate, I_COMMON_WEDNESDAY, -1, 0);
 }
@@ -553,6 +556,8 @@ validate_evolution_event_22(const I_event *ievent, gint stage)
 void
 validate_evolution_event_23(const I_event *ievent, gint stage)
 {
+	gint rdate[3] = {31,8,2016};
+
 	log_bitmask(stage);
 
 	/*
@@ -578,7 +583,6 @@ validate_evolution_event_23(const I_event *ievent, gint stage)
 			NULL, NULL, ICOMMON_SENSITIVITY_PUBLIC,
 			NULL, "2010-08-25 15:36:55", stage);
 
-	gint rdate[3] = {31,8,2016};
 	validate_recurrence(ievent->incidence->recurrence,
 			I_REC_CYCLE_YEARLY_MONTHDAY, 2, 0, rdate, 0, 31, I_COMMON_AUG);
 }
@@ -645,15 +649,15 @@ validate_evolution_event_25(const I_event *ievent, gint stage)
 	 * </recurrence>
 	 */
 	validate_recurrence(ievent->incidence->recurrence,
-			I_REC_CYCLE_DAILY,		// Recurrence_cycle
-			2,			// interval
-			13,			// range_number
-			NULL,		// range_date
-			0,			// weekdays
-			0,			// day_number
-			I_COMMON_MONTH_NULL);	// month
+			I_REC_CYCLE_DAILY,	/* Recurrence_cycle	*/
+			2,			/* interval		*/
+			13,			/* range_number		*/
+			NULL,			/* range_date		*/
+			0,			/* weekdays		*/
+			0,			/* day_number		*/
+			I_COMMON_MONTH_NULL);	/* month		*/
 
-	// exclusions
+	/* exclusions */
 	g_assert(ievent->incidence->recurrence->exclusion != NULL);
 	assert_GDate_in_list(ievent->incidence->recurrence->exclusion, "2010-09-08");
 	assert_GDate_in_list(ievent->incidence->recurrence->exclusion, "2010-09-17");
@@ -769,13 +773,13 @@ validate_evolution_event_30(const I_event *ievent, gint stage)
 	g_assert(ievent->incidence->recurrence != NULL);
 
 	validate_recurrence(ievent->incidence->recurrence,
-			I_REC_CYCLE_YEARLY_WEEKDAY,	// Recurrence_cycle
-			1,			// interval
-			10,			// range_number
-			NULL,		// range_date
-			2,			// weekdays
-			4,			// day_number
-			I_COMMON_FEB);		// month
+			I_REC_CYCLE_YEARLY_WEEKDAY,	/* Recurrence_cycle	*/
+			1,				/* interval		*/
+			10,				/* range_number		*/
+			NULL,				/* range_date		*/
+			2,				/* weekdays		*/
+			4,				/* day_number		*/
+			I_COMMON_FEB);			/* month		*/
 }
 
 void
@@ -797,11 +801,11 @@ validate_evolution_event_tz1(const I_event *ievent, gint stage)
 			strip_cr_cpy(ievent->incidence->common->vtimezone));
 
 	validate_iincidence(ievent->incidence,
-			"event_tz1", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-11-03 14:30:00", // startdate
+			"event_tz1", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-11-03 14:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -837,11 +841,11 @@ validate_evolution_event_tz2(const I_event *ievent, gint stage)
 			strip_cr_cpy(ievent->incidence->common->vtimezone));
 
 	validate_iincidence(ievent->incidence,
-			"event_tz2", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-11-03 08:30:00", // startdate
+			"event_tz2", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-11-03 08:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -877,11 +881,11 @@ validate_evolution_event_tz3(const I_event *ievent, gint stage)
 			strip_cr_cpy(ievent->incidence->common->vtimezone));
 
 	validate_iincidence(ievent->incidence,
-			"event_tz3", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-11-03 14:30:00", // startdate
+			"event_tz3", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-11-03 14:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -917,11 +921,11 @@ validate_evolution_event_tz4(const I_event *ievent, gint stage)
 			strip_cr_cpy(ievent->incidence->common->vtimezone));
 
 	validate_iincidence(ievent->incidence,
-			"event_tz4", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-11-02 23:30:00", // startdate
+			"event_tz4", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-11-02 23:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -957,11 +961,11 @@ validate_evolution_event_tz5(const I_event *ievent, gint stage)
 			strip_cr_cpy(ievent->incidence->common->vtimezone));
 
 	validate_iincidence(ievent->incidence,
-			"event_tz5", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-11-03 11:05:00", // startdate
+			"event_tz5", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-11-03 11:05:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -978,11 +982,11 @@ validate_evolution_event_tz6(const I_event *ievent, gint stage)
 	g_assert(ievent->incidence->common->vtimezone == NULL);
 
 	validate_iincidence(ievent->incidence,
-			"event_tz6", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2010-11-04 11:13:00", // startdate
+			"event_tz6", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2010-11-04 11:13:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -1020,11 +1024,11 @@ validate_evolution_event_tz7(const I_event *ievent, gint stage)
 	assert_equal("start date before DST, end date in DST", ievent->incidence->common->body);
 
 	validate_iincidence(ievent->incidence,
-			"event_tz7", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2011-03-27 00:30:00", // startdate
+			"event_tz7", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2011-03-27 00:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -1062,11 +1066,11 @@ validate_evolution_event_tz8(const I_event *ievent, gint stage)
 	assert_equal("start date in DST, end date after DST", ievent->incidence->common->body);
 
 	validate_iincidence(ievent->incidence,
-			"event_tz8", // summary
-			NULL, // location
-			NULL, // organizer displayname
-			NULL, // organizer smtp-address
-			"2011-10-29 23:30:00", // startdate
+			"event_tz8", /* summary */
+			NULL, /* location */
+			NULL, /* organizer displayname */
+			NULL, /* organizer smtp-address */
+			"2011-10-29 23:30:00", /* startdate */
 			stage);
 
 	g_assert(ievent->incidence->recurrence == NULL);
@@ -1095,7 +1099,10 @@ validate_evolution_event_r1(const I_event *ievent, gint stage)
 void
 validate_evolution_event_b1(const I_event *ievent, gint stage)
 {
-
+	Alarm *mail_alarm = NULL;
+	
+	(void)stage;
+	
 	/* resulting alarm should look like this in kolab:
 	<advanced-alarms>
 		<alarm type="email">
@@ -1112,10 +1119,10 @@ validate_evolution_event_b1(const I_event *ievent, gint stage)
 	 */
 
 
-	// advanced alarms
+	/* advanced alarms */
 	g_assert_cmpint(g_list_length(ievent->incidence->advanced_alarm), ==, 1);
-	// this is a mapped simple alarm from kolab
-	Alarm *mail_alarm = assert_Alarm_in_list(ievent->incidence->advanced_alarm,
+	/* this is a mapped simple alarm from kolab */
+	mail_alarm = assert_Alarm_in_list(ievent->incidence->advanced_alarm,
 						 I_ALARM_TYPE_EMAIL,
 						 -15,
 						 0,
@@ -1138,6 +1145,8 @@ validate_evolution_event_b1(const I_event *ievent, gint stage)
 void
 validate_evolution_event_b2(const I_event *ievent, gint stage)
 {
+	(void)stage;
+	
 	g_assert_cmpint(g_list_length(ievent->incidence->attendee), ==, 5);
 	assert_attendee_in_list(ievent->incidence->attendee, "Individual",
 			"h.helwich@tarent.de", I_INC_STATUS_NONE, TRUE, FALSE, I_INC_ROLE_REQUIRED, I_INC_CUTYPE_INDIVIDUAL);
