@@ -28,18 +28,20 @@
 #include <gmime/gmime.h>
 #include <string.h>
 #include <kolab-conv.h>
-#include <libxml/tree.h>	// XML parsing
+#include <libxml/tree.h>	/* XML parsing */
 
 void
 assert_equal(gchar *expected, GString *value)
 {
+	GString *expected_str = NULL;
+	
 	g_debug("testing if string value '%s' is equal to expected value '%s'", value ? value->str : NULL, expected);
 	if (expected == NULL) {
 		g_assert(value == NULL);
 		return;
 	}
 	g_assert(value != NULL);
-	GString *expected_str = g_string_new(expected);
+	expected_str = g_string_new(expected);
 	g_assert(g_string_equal(expected_str, value));
 	g_string_free(expected_str, TRUE);
 }
@@ -73,17 +75,20 @@ assert_equal_double (gdouble expected, gdouble value)
 void
 assert_equal_gdate(gchar *expected, GDate *gdate)
 {
+	gchar *gstr = NULL;
+	GString *gstr_new = NULL;
+	
 	if (expected == NULL) {
 		g_assert(gdate == NULL);
 		return;
 	}
 
-	gchar *gstr = g_strdup_printf("%04d-%02d-%02d",
+	gstr = g_strdup_printf("%04d-%02d-%02d",
 			g_date_get_year (gdate),
 			g_date_get_month (gdate),
 			g_date_get_day (gdate));
 
-	GString *gstr_new = g_string_new(gstr);
+	gstr_new = g_string_new(gstr);
 	assert_equal(expected, gstr_new);
 
 	g_free(gstr);
@@ -93,10 +98,14 @@ assert_equal_gdate(gchar *expected, GDate *gdate)
 void
 assert_equal_timestamp(gchar *expected, time_t *timestamp)
 {
+	struct tm *ts = NULL;
+	gchar *tstr = NULL;
+	
 	g_debug("timestamp: %lu", *timestamp);
-	struct tm *ts = gmtime(timestamp);
 
-	gchar *tstr = g_strdup_printf("%04d-%02d-%02d %02d:%02d:%02d",
+	ts = gmtime(timestamp);
+
+	tstr = g_strdup_printf("%04d-%02d-%02d %02d:%02d:%02d",
 			ts->tm_year + 1900,
 			ts->tm_mon + 1,
 			ts->tm_mday,
@@ -112,11 +121,13 @@ assert_equal_timestamp(gchar *expected, time_t *timestamp)
 }
 
 void
-assert_timestamp_not_older_than_10_seconds(time_t *timestamp) {
-
+assert_timestamp_not_older_than_10_seconds(time_t *timestamp)
+{
+	time_t now = NULL;
+	
 	g_debug("timestamp: %lu", *timestamp);
 
-	time_t now = time(NULL);
+	now = time(NULL);
 
 	g_assert(*timestamp <= now);
 
@@ -130,11 +141,11 @@ assert_timestamp_not_older_than_10_seconds(time_t *timestamp) {
 Phone_number*
 assert_phone_in_list (GList *phone_nrs, gchar *nr_expected, Icontact_phone_type type_expected)
 {
-	gint found_type = 0; // type found?
-	gint matched_number = 0; // numbers match?
-
-	g_assert (phone_nrs != NULL);
+	gint found_type = 0; /* type found? */
+	gint matched_number = 0; /* numbers match? */
 	Phone_number *ret = NULL;
+	
+	g_assert (phone_nrs != NULL);
 
 	while (phone_nrs != NULL) {
 		Phone_number *p = phone_nrs->data;
@@ -145,7 +156,7 @@ assert_phone_in_list (GList *phone_nrs, gchar *nr_expected, Icontact_phone_type
 
 			if (p->type == type_expected)
 			{
-				found_type = 1; // types match
+				found_type = 1; /* types match */
 				g_debug ("matching type '%d' found", type_expected);
 				g_debug ("testing if number '%s' is equal to expected number '%s'",
 						p->number, nr_expected ? nr_expected : NULL);
@@ -190,9 +201,10 @@ assert_list_length(GList *value, gint lenght_exp) {
 Email*
 assert_email_in_list (GList *emails, gchar *smtp_address_exp, gchar *display_name_exp)
 {
-	g_assert (emails != NULL);
 	Email *ret = NULL;
 
+	g_assert (emails != NULL);
+
 	while (emails != NULL) {
 		Email *e = emails->data;
 
@@ -201,7 +213,7 @@ assert_email_in_list (GList *emails, gchar *smtp_address_exp, gchar *display_nam
 
 		g_assert (e != NULL);
 
-		// assert display_name
+		/* assert display_name */
 		if (display_name_exp == NULL) {
 			g_assert(e->display_name == NULL);
 			matched_display_name = 1;
@@ -210,7 +222,7 @@ assert_email_in_list (GList *emails, gchar *smtp_address_exp, gchar *display_nam
 			matched_display_name = 1;
 		}
 
-		// assert smtp_address
+		/* assert smtp_address */
 		if (smtp_address_exp == NULL) {
 			g_assert(e->smtp_address == NULL);
 			matched_smtp_address = 1;
@@ -241,6 +253,8 @@ assert_address_in_list (GList *addresses,
 		gchar *postal_code,
 		gchar *country)
 {
+	(void)type;
+	
 	g_assert (addresses != NULL);
 
 	while (addresses != NULL) {
@@ -255,7 +269,7 @@ assert_address_in_list (GList *addresses,
 
 		g_assert (addr != NULL);
 
-		// street
+		/* street */
 		if (street == NULL) {
 			if(addr->street == NULL) {
 				matched_street = 1;
@@ -264,7 +278,7 @@ assert_address_in_list (GList *addresses,
 		else if (strcmp(addr->street->str, street) == 0){
 			matched_street = 1;
 		}
-		// pobox
+		/* pobox */
 		if (pobox == NULL) {
 			if(addr->pobox == NULL) {
 				matched_pobox = 1;
@@ -273,7 +287,7 @@ assert_address_in_list (GList *addresses,
 		else if (strcmp(addr->pobox->str, pobox) == 0){
 			matched_pobox = 1;
 		}
-		// locality
+		/* locality */
 		if (locality == NULL) {
 			if(addr->locality == NULL) {
 				matched_locality = 1;
@@ -282,7 +296,7 @@ assert_address_in_list (GList *addresses,
 		else if (strcmp(addr->locality->str, locality) == 0){
 			matched_locality = 1;
 		}
-		// region
+		/* region */
 		if (region == NULL) {
 			if(addr->region == NULL) {
 				matched_region = 1;
@@ -291,7 +305,7 @@ assert_address_in_list (GList *addresses,
 		else if (strcmp(addr->region->str, region) == 0){
 			matched_region = 1;
 		}
-		// postal_code
+		/* postal_code */
 		if (postal_code == NULL) {
 			if(addr->postal_code == NULL) {
 				matched_postal_code = 1;
@@ -300,7 +314,7 @@ assert_address_in_list (GList *addresses,
 		else if (strcmp(addr->postal_code->str, postal_code) == 0){
 			matched_postal_code = 1;
 		}
-		// country
+		/* country */
 		if (street == NULL) {
 			if(addr->country == NULL) {
 				matched_country = 1;
@@ -331,10 +345,13 @@ assert_Alarm_in_list (GList *advancedAlarm, Alarm_type type, gint start_offset,
 					  gchar *proc_param_program, gchar *proc_param_arguments,
 					  gchar *email_param_subject, gchar *email_param_mail_text)
 {
-	if (advancedAlarm != NULL)	// evolution tasks have no advanced_alarm
+	if (advancedAlarm != NULL)	/* evolution tasks have no advanced_alarm */
 	{
 		while (advancedAlarm != NULL) {
 				Alarm *alarm = advancedAlarm->data;
+				gint failed = 0; /* bitmap for error location */
+				char *bm = NULL;
+
 				g_assert (alarm != NULL);
 
 				g_debug ("advancedAlarm values: "
@@ -357,8 +374,6 @@ assert_Alarm_in_list (GList *advancedAlarm, Alarm_type type, gint start_offset,
 						alarm->email_param && alarm->email_param->subject ? alarm->email_param->subject->str : "NULL",
 						alarm->email_param && alarm->email_param->mail_text ? alarm->email_param->mail_text->str : "NULL");
 
-				gint failed = 0; // bitmap for error location
-
 				CHECK_FAILED(alarm->type == type, failed, 1);
 				CHECK_FAILED(alarm->start_offset == start_offset, failed, 2);
 				CHECK_FAILED(alarm->end_offset == end_offset, failed, 3);
@@ -368,12 +383,12 @@ assert_Alarm_in_list (GList *advancedAlarm, Alarm_type type, gint start_offset,
 				CHECK_FAILED(audio_file == NULL || strcmp(alarm->audio_file->str, audio_file) == 0, failed, 7);
 				CHECK_FAILED(proc_param_program == NULL || strcmp(alarm->proc_param->program->str, proc_param_program) == 0, failed, 8);
 				CHECK_FAILED(proc_param_arguments == NULL || strcmp(alarm->proc_param->arguments->str, proc_param_arguments) == 0, failed, 9);
-				// email_param addresses list - own function assert_String_in_list()
+				/* email_param addresses list - own function assert_String_in_list() */
 				CHECK_FAILED(email_param_subject == NULL || strcmp(alarm->email_param->subject->str, email_param_subject) == 0, failed, 10);
 				CHECK_FAILED(email_param_mail_text == NULL || strcmp(alarm->email_param->mail_text->str, email_param_mail_text) == 0, failed, 11);
-				// email_param attachments list - own function assert_String_in_list()
+				/* email_param attachments list - own function assert_String_in_list() */
 
-				char *bm = int_to_bitmask(failed);
+				bm = int_to_bitmask(failed);
 				g_debug ("checks for alarm: %s", bm);
 				g_free(bm);
 
@@ -420,14 +435,15 @@ assert_GDate_in_list(GList *date_list, gchar *value)
 {
 	while (date_list != NULL)
 	{
+		gchar *gstr = NULL;
 		GDate *date_element = date_list->data;
 
 		g_assert (date_element != NULL);
 
-		gchar *gstr = g_strdup_printf("%04d-%02d-%02d",
-					  date_element->year,
-					  date_element->month,
-					  date_element->day);
+		gstr = g_strdup_printf("%04d-%02d-%02d",
+		                       date_element->year,
+		                       date_element->month,
+		                       date_element->day);
 
 		g_debug ("testing if date '%s' matches expected date '%s'", gstr, value);
 
@@ -473,12 +489,14 @@ assert_custom_field_in_list (GList *custom_list, gchar *custom_field_type, gchar
 	g_assert_not_reached();
 }
 
-// set value NULL in function call if element not available
+/* set value NULL in function call if element not available */
 void
 validate_iincidence(const I_incidence *iincidence, gchar *summary, gchar *location,
 		gchar *organizer_display_name, gchar *organizer_smtp_address,
 		gchar* start_date, gint stage)
 {
+	(void)stage;
+	
 	g_assert(iincidence != NULL);
 
 	assert_equal(summary, iincidence->summary);
@@ -496,9 +514,10 @@ validate_iincidence(const I_incidence *iincidence, gchar *summary, gchar *locati
 	} else {
 		g_assert(iincidence->start_date == NULL);
 	}
-	// advanced_alarm (own function: assert_alarm_in_list())
-	// recurrence (own function: validate_recurrence())
-	// attendee-list (own function: assert_attendee_in_list())
+	/* advanced_alarm (own function: assert_alarm_in_list())
+	 * recurrence (own function: validate_recurrence())
+	 * attendee-list (own function: assert_attendee_in_list())
+	 */
 }
 
 void
@@ -506,9 +525,9 @@ validate_icommon(const I_common *icommon, gchar* exp_product_id, gchar* exp_uid,
 		gchar *exp_body, gchar *exp_categories, Sensitivity exp_sensitivity, gchar *exp_creation_date, gchar *exp_last_modification_date, gint stage)
 {
 	g_assert(icommon != NULL);
-	if (IS_TEST_STAGE_INTERN_TO_KMAIL(stage)) // own value is written when kolab xml is created
+	if (IS_TEST_STAGE_INTERN_TO_KMAIL(stage)) /* own value is written when kolab xml is created */
 		exp_product_id = KOLABCONV_PRODUCT_ID;
-	else if (IS_TEST_STAGE_EVO_TO_INTERN(stage)) // product id cannot be retrieved from evolution type
+	else if (IS_TEST_STAGE_EVO_TO_INTERN(stage)) /* product id cannot be retrieved from evolution type */
 		exp_product_id = NULL;
 	assert_equal(exp_product_id, icommon->product_id);
 	assert_equal(exp_uid, icommon->uid);
@@ -532,7 +551,7 @@ validate_icommon(const I_common *icommon, gchar* exp_product_id, gchar* exp_uid,
 	 * use the current system time for creation-date and last-modification-date.
 	 */
 
-	// The dates should never be NULL
+	/* The dates should never be NULL */
 	g_assert(icommon->creation_datetime != NULL);
 	g_assert(icommon->creation_datetime->date_time != NULL);
 	g_assert(icommon->last_modified_datetime != NULL);
@@ -545,19 +564,19 @@ validate_icommon(const I_common *icommon, gchar* exp_product_id, gchar* exp_uid,
 	}
 	else if(exp_creation_date == NULL && exp_last_modification_date != NULL)
 	{
-		//libekolabconv should have set last_modification_date as creation-date
+		/* libekolabconv should have set last_modification_date as creation-date */
 		assert_equal_timestamp(exp_last_modification_date, icommon->creation_datetime->date_time);
 		assert_equal_timestamp(exp_last_modification_date, icommon->last_modified_datetime->date_time);
 	}
 	else if(exp_creation_date != NULL && exp_last_modification_date == NULL)
 	{
-		//libekolabconv should have set creation_date as last_modification_date
+		/* libekolabconv should have set creation_date as last_modification_date */
 		assert_equal_timestamp(exp_creation_date, icommon->creation_datetime->date_time);
 		assert_equal_timestamp(exp_creation_date, icommon->last_modified_datetime->date_time);
 	}
 	else
 	{
-		// libekolabconv should have used current system time for both
+		/* libekolabconv should have used current system time for both */
 		assert_timestamp_not_older_than_10_seconds(icommon->creation_datetime->date_time);;
 		assert_timestamp_not_older_than_10_seconds(icommon->last_modified_datetime->date_time);
 	}
@@ -607,6 +626,11 @@ validate_recurrence(const Recurrence *recurrence, Recurrence_cycle cycle,
 void
 assert_binary_attachment_equal(gchar *exp_data_file_name, gchar *name_exp, gchar *mime_type_exp, Kolab_conv_mail_part *value) {
 
+	FILE *file;
+	gchar *buffer;
+	gulong fileLen;
+	gint result;
+
 	g_assert(value != NULL);
 
 	g_assert_cmpstr(name_exp, ==, value->name);
@@ -614,11 +638,7 @@ assert_binary_attachment_equal(gchar *exp_data_file_name, gchar *name_exp, gchar
 
 	g_debug("testing if attached binary value is equal to content of file '%s'", exp_data_file_name);
 
-	FILE *file;
-	gchar *buffer;
-	gulong fileLen;
-
-	//Open file
+	/* Open file */
 	file = fopen(exp_data_file_name, "rb");
 
 	if(!file) {
@@ -627,13 +647,13 @@ assert_binary_attachment_equal(gchar *exp_data_file_name, gchar *name_exp, gchar
 		assert(FALSE);
 	}
 
-	//Get file length
+	/* Get file length */
 	fseek(file, 0, SEEK_END);
 	fileLen = ftell(file);
 	g_assert_cmpint(fileLen, ==, value->length);
 	fseek(file, 0, SEEK_SET);
 
-	//Allocate memory
+	/* Allocate memory */
 	buffer = g_new0(gchar, fileLen+1);
 	if(!buffer) {
 
@@ -642,19 +662,16 @@ assert_binary_attachment_equal(gchar *exp_data_file_name, gchar *name_exp, gchar
 		return;
 	}
 
-	//Read file contents into buffer
+	/* Read file contents into buffer */
 	fread(buffer, fileLen, 1, file);
 	fclose(file);
 
-	gint result = memcmp(buffer, value->data, fileLen);
+	result = memcmp(buffer, value->data, fileLen);
 	g_free(buffer);
 
 	g_assert(result == 0);
 }
 
-
-
-
 void
 assert_binary_attachment_store_equal(gchar *exp_data_file_name, gchar *name_exp, gchar *mime_type_exp, I_common *icommon, gint idx) {
 	Kolab_conv_mail_part *value = g_list_nth_data(icommon->kolab_attachment_store, idx);
@@ -701,11 +718,14 @@ void
 validate_kolab_store_xml(GList *elements, gint index, gchar *name)
 {
 	GList *elem = g_list_nth(elements, index);
+	gchar *xml_str = NULL;
+	xmlDocPtr tree = NULL;
+	
 	g_assert(elem != NULL);
 
-	gchar *xml_str = (gchar*)elem->data;
-//	gchar *xml_str = (gchar*)g_list_nth(elements, index)->data;
-	xmlDocPtr tree = xmlReadMemory (xml_str, strlen (xml_str), "test.xml", NULL, 0);
+	xml_str = (gchar*)elem->data;
+	/* gchar *xml_str = (gchar*)g_list_nth(elements, index)->data; */
+	tree = xmlReadMemory (xml_str, strlen (xml_str), "test.xml", NULL, 0);
 	g_assert(tree->type == XML_DOCUMENT_NODE);
 	g_assert(tree->children != NULL);
 	g_assert(tree->children->type == XML_ELEMENT_NODE);
@@ -751,9 +771,9 @@ void
 validate_link_attachments(const I_common *icommon, ...)
 {
         va_list ap;
-        va_start(ap, icommon);
         gchar* v1, *v2;
         GList *lal = icommon->link_attachments;
+	va_start(ap, icommon);
         for (; lal != NULL; lal = lal->next) {
         	v1 = (gchar*) lal->data;
         	v2 = va_arg(ap, gchar*);
@@ -768,9 +788,9 @@ void
 validate_inline_attachment_names(const I_common *icommon, ...)
 {
         va_list ap;
-        va_start(ap, icommon);
         gchar* v1, *v2;
         GList *lal = icommon->inline_attachment_names;
+	va_start(ap, icommon);
         for (; lal != NULL; lal = lal->next) {
         	v1 = (gchar*) lal->data;
         	v2 = va_arg(ap, gchar*);
