@@ -25,8 +25,8 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include <unistd.h> // getcwd() definition
-#include <sys/param.h> // MAXPATHLEN definition
+#include <unistd.h> /* getcwd() definition */
+#include <sys/param.h> /* MAXPATHLEN definition */
 #include <libecal/e-cal-component.h>
 #include <kolab-conv.h>
 #include <evolution/evolution.h>
@@ -39,7 +39,6 @@
 #include "main.h"
 #include "testbase.h"
 
-
 /**
  * A structure which contains the needed arguments of a test
  */
@@ -55,7 +54,7 @@
  * @param  fmt
  *         a formatted message like in printf
  */
-void
+static void
 check_error (GError *error, gchar *fmt, ...)
 {
 	if (error != NULL) {
@@ -76,58 +75,66 @@ check_error (GError *error, gchar *fmt, ...)
  *         A filename of a kolab email file
  * @return A kolab mail struct
  */
-Kolab_conv_mail*
+static Kolab_conv_mail*
 read_kolab_email_file_tested (const gchar* filename, gint *stage)
 {
 	GError *error = NULL;
-	// read kolab mail file to the kolab mail struct
+	Kolab_conv_mail *mail = NULL;
+	
+	/* read kolab mail file to the kolab mail struct */
 	g_message("reading email file %s to a kolab mail struct", filename);
-	Kolab_conv_mail* mail = read_kolab_email_file (filename, &error);
+	mail = read_kolab_email_file (filename, &error);
 	check_error (error, "error while reading kolab email file %s", filename);
 	*stage |= TEST_STAGE_FILE_TO_KMAIL;
 	return mail;
 }
 
-void
+static void
 write_kolab_email_file_tested (const gchar* filename, Kolab_conv_mail* mail, gint *stage)
 {
 	GError *error = NULL;
-	// write temporary kolab mail file
+	/* write temporary kolab mail file */
 	g_message("writing kolab mail struct to email file %s", filename);
 	write_kolab_email_file(mail, filename, &error);
 	check_error (error, "error while writing kolab email file %s", filename);
 	*stage |= TEST_STAGE_KMAIL_TO_FILE;
 }
 
-gchar*
+static gchar*
 create_evolution_vcard_tested_I_contact (const EContact* econtact, gint *stage)
 {
+	EVCardFormat version = EVC_FORMAT_VCARD_30;
+	gchar *vcard_str = NULL;
+
 	g_message("serializing evolution contact to vCard 3.0 string");
 
-	EVCardFormat version = EVC_FORMAT_VCARD_30;
-	gchar *vcard_str = e_vcard_to_string ((EVCard *) econtact, version);
+	vcard_str = e_vcard_to_string ((EVCard *) econtact, version);
 
 	*stage |= TEST_STAGE_EVO_TO_FILE;
 	return vcard_str;
 }
 
-gchar*
+static gchar*
 create_evolution_vcard_tested (const ECalComponentWithTZ* epim, gint *stage)
 {
+	icalcomponent *ical_vevent = NULL;
+	icalcomponent *ical_vcal = NULL;
+	icalcomponent *ical_vtz = NULL;
+	gchar *ical_str = NULL;
+	
 	g_log ("libekolabconv", G_LOG_LEVEL_MESSAGE,
 			"serializing evolution event to vCard 3.0 string");
-	icalcomponent *ical_vevent = e_cal_component_get_icalcomponent (
+	ical_vevent = e_cal_component_get_icalcomponent (
 			(ECalComponent*) epim->maincomp);
-	icalcomponent *ical_vcal = icalcomponent_new_vcalendar ();
-	icalcomponent *ical_vtz = NULL;
+	ical_vcal = icalcomponent_new_vcalendar ();
 	if (epim->timezone != ((void *) 0)) {
 		ical_vtz = e_cal_component_get_icalcomponent (
 				(ECalComponent*) epim->timezone);
 		icalcomponent_add_component (ical_vcal, ical_vtz);
 	}
 	icalcomponent_add_component (ical_vcal, ical_vevent);
-	gchar *ical_str = icalcomponent_as_ical_string (ical_vcal);
-	// free allocated resources
+	ical_str = icalcomponent_as_ical_string (ical_vcal);
+	/* free allocated resources */
 	if (ical_vtz != NULL)
 		icalcomponent_remove_component(ical_vcal, ical_vtz);
 	icalcomponent_remove_component(ical_vcal, ical_vevent);
@@ -137,47 +144,57 @@ create_evolution_vcard_tested (const ECalComponentWithTZ* epim, gint *stage)
 }
 
 
-gchar*
+static gchar*
 create_evolution_vcard_tested_I_event (const ECalComponentWithTZ* eevent, gint *stage)
 {
 	return create_evolution_vcard_tested(eevent, stage);
 }
 
-gchar*
+static gchar*
 create_evolution_vcard_tested_I_task (const ECalComponentWithTZ* eetask, gint *stage)
 {
 	return create_evolution_vcard_tested(eetask, stage);
 }
 
-gchar*
+static gchar*
 create_evolution_vcard_tested_I_note (const ECalComponentWithTZ* enote, gint *stage)
 {
 	return create_evolution_vcard_tested(enote, stage);
 }
 
-EContact*
+static EContact*
 process_evolution_vcard_tested_I_contact (const gchar* vcard_str, gint *stage)
 {
+	EContact *econtact = NULL;
+	
 	g_message("deserializing evolution contact from vCard 3.0 string");
-	EContact *econtact = e_contact_new_from_vcard(vcard_str);
+	econtact = e_contact_new_from_vcard(vcard_str);
 	*stage |= TEST_STAGE_FILE_TO_EVO;
 	return econtact;
 }
 
-ECalComponentWithTZ*
+static ECalComponentWithTZ*
 process_evolution_vcard_tested (const gchar* vcard_str, icalcomponent_kind kind, gint *stage)
 {
+	icalcomponent *ical_vcal = NULL;
+	icalcomponent *ical_vevent = NULL;
+	icalcomponent *ical_vtz = NULL;
+	ECalComponent *epim = NULL;
+	ECalComponent *etz = NULL;
+	ECalComponentWithTZ *ectz = NULL;
+	gboolean success = FALSE;
+	
 	g_message("deserializing evolution instance from vCard 3.0 string");
-	icalcomponent *ical_vcal = icalcomponent_new_from_string( vcard_str );
-	icalcomponent *ical_vevent = icalcomponent_get_first_component ( ical_vcal, kind );
-	ECalComponent *epim = e_cal_component_new();
-	gboolean success =  e_cal_component_set_icalcomponent (epim,  icalcomponent_new_clone ( ical_vevent ));
+	ical_vcal = icalcomponent_new_from_string( vcard_str );
+	ical_vevent = icalcomponent_get_first_component ( ical_vcal, kind );
+	epim = e_cal_component_new();
+	success = e_cal_component_set_icalcomponent (epim,  icalcomponent_new_clone ( ical_vevent ));
 	g_assert(success);
-	icalcomponent *ical_vtz = icalcomponent_get_first_component ( ical_vcal, ICAL_VTIMEZONE_COMPONENT );
-	ECalComponent *etz = e_cal_component_new();
+	ical_vtz = icalcomponent_get_first_component ( ical_vcal, ICAL_VTIMEZONE_COMPONENT );
+	etz = e_cal_component_new();
 	success =  e_cal_component_set_icalcomponent (etz,  icalcomponent_new_clone ( ical_vtz ));
 	g_assert(success);
-	ECalComponentWithTZ *ectz = g_new0(ECalComponentWithTZ, 1);
+	ectz = g_new0(ECalComponentWithTZ, 1);
 	ectz->maincomp = epim;
 	ectz->timezone = etz;
 	*stage |= TEST_STAGE_FILE_TO_EVO;
@@ -185,53 +202,53 @@ process_evolution_vcard_tested (const gchar* vcard_str, icalcomponent_kind kind,
 	return ectz;
 }
 
-ECalComponentWithTZ*
+static ECalComponentWithTZ*
 process_evolution_vcard_tested_I_event (const gchar* vcard_str, gint *stage)
 {
 	return process_evolution_vcard_tested(vcard_str, ICAL_VEVENT_COMPONENT, stage);
 }
 
-ECalComponentWithTZ*
+static ECalComponentWithTZ*
 process_evolution_vcard_tested_I_task (const gchar* vcard_str, gint *stage)
 {
 	return process_evolution_vcard_tested(vcard_str, ICAL_VTODO_COMPONENT, stage);
 }
 
-ECalComponentWithTZ*
+static ECalComponentWithTZ*
 process_evolution_vcard_tested_I_note (const gchar* vcard_str, gint *stage)
 {
 	return process_evolution_vcard_tested(vcard_str, ICAL_VJOURNAL_COMPONENT, stage);
 }
 
-
-
-gchar*
+static gchar*
 read_text_file_tested (const gchar* filename)
 {
 	GError *error = NULL;
 	gchar *contents = NULL;
+	gboolean success = FALSE;
 	g_message("reading file %s to memory", filename);
-	gboolean success = g_file_get_contents(filename, &contents, NULL, &error);
+	success = g_file_get_contents(filename, &contents, NULL, &error);
 	g_assert(success);
 	check_error (error, "error while processing kolab email struct");
 	return contents;
 }
 
-void
+static void
 free_after_test(gpointer ptr)
 {
 	free_mem_after_test = g_list_append(free_mem_after_test, ptr);
 }
 
 #define process_kolab_tested(PIM_TYPE) \
-PIM_TYPE*\
+static PIM_TYPE*\
 process_kolab_tested_##PIM_TYPE (const Kolab_conv_mail* kmail, void\
 (*testData) (const PIM_TYPE*, gint stage), gint *stage)\
 {\
 	GError *error = NULL;\
+	PIM_TYPE *ipim = NULL;\
 	/* convert kolab mail struct to a typed interchange struct */\
 	g_message("converting kolab mail struct to an interchange struct");\
-	PIM_TYPE *ipim = conv_kolab_conv_mail_to_##PIM_TYPE (kmail, &error);\
+	ipim = conv_kolab_conv_mail_to_##PIM_TYPE (kmail, &error);\
 	check_error (error, "error while processing kolab email struct");\
 	*stage |= TEST_STAGE_KMAIL_TO_INTERN;\
 	/* test interchange struct */\
@@ -246,12 +263,13 @@ process_kolab_tested(I_task)
 process_kolab_tested(I_note)
 
 #define create_kolab_tested(PIM_TYPE) \
-Kolab_conv_mail*\
+static Kolab_conv_mail*\
 create_kolab_tested_##PIM_TYPE (PIM_TYPE* ipim, void\
 (*testData) (const PIM_TYPE*, gint stage), gint *stage)\
 {\
 	GError *error = NULL;\
 	Kolab_conv_mail *mail = NULL;\
+	(void)testData;\
 	\
 	/* convert kolab mail struct to a typed interchange struct */\
 	g_message("converting interchange struct to kolab mail struct");\
@@ -269,14 +287,15 @@ create_kolab_tested(I_task)
 create_kolab_tested(I_note)
 
 #define process_evolution_tested(EVO_TYPE, PIM_TYPE) \
-PIM_TYPE*\
+static PIM_TYPE*\
 process_evolution_tested_##PIM_TYPE (const EVO_TYPE* epim, void\
 (*testData) (const PIM_TYPE*, gint stage), gint *stage)\
 {\
 	GError *error = NULL;\
+	PIM_TYPE *ipim = NULL;\
 	/* convert to interchange struct again */\
 	g_message("converting evolution contact to interchange contact struct");\
-	PIM_TYPE *ipim = conv_##EVO_TYPE##_to_##PIM_TYPE (epim, &error);\
+	ipim = conv_##EVO_TYPE##_to_##PIM_TYPE (epim, &error);\
 	check_error (error, "error while processing evolution contact");\
 	*stage |= TEST_STAGE_EVO_TO_INTERN;\
 	\
@@ -292,18 +311,21 @@ process_evolution_tested(ECalComponentWithTZ, I_task)
 process_evolution_tested(ECalComponentWithTZ, I_note)
 
 #define create_evolution_tested(EVO_TYPE, PIM_TYPE) \
-EVO_TYPE*\
+static EVO_TYPE*\
 create_evolution_tested_##PIM_TYPE (PIM_TYPE* ipim, void\
 (*testData) (const PIM_TYPE*, gint stage), gint *stage)\
 {\
 	GError *error = NULL;\
+	EVO_TYPE *epim = NULL;\
+	gint dummystage = 0;\
+	gchar *vcard = NULL;\
+	(void)testData;\
 	/* convert to interchange struct again */\
 	g_message("converting interchange contact struct to an evolution contact");\
-	EVO_TYPE *epim = conv_##PIM_TYPE##_to_##EVO_TYPE (&ipim, &error);\
+	epim = conv_##PIM_TYPE##_to_##EVO_TYPE (&ipim, &error);\
 	check_error (error, "error while creating evolution contact");\
 	g_assert(ipim == NULL);\
-	gint dummystage = 0;\
-	gchar *vcard = create_evolution_vcard_tested_##PIM_TYPE(epim, &dummystage);\
+	vcard = create_evolution_vcard_tested_##PIM_TYPE(epim, &dummystage);\
 	log_debug("%s", vcard);\
 	g_free(vcard);\
 	*stage |= TEST_STAGE_INTERN_TO_EVO;\
@@ -322,28 +344,28 @@ create_evolution_tested(ECalComponentWithTZ, I_event)
 create_evolution_tested(ECalComponentWithTZ, I_task)
 create_evolution_tested(ECalComponentWithTZ, I_note)
 
-void
+static void
 free_I_contact(I_contact **ipim)
 {
 	generic_g_list_free (&(*ipim)->common->kolab_attachment_store, kolabconv_free_kmail_part);
 	free_i_contact(ipim);
 }
 
-void
+static void
 free_I_event(I_event **ipim)
 {
 	generic_g_list_free (&(*ipim)->incidence->common->kolab_attachment_store, kolabconv_free_kmail_part);
 	free_i_event(ipim);
 }
 
-void
+static void
 free_I_task(I_task **ipim)
 {
 	generic_g_list_free (&(*ipim)->incidence->common->kolab_attachment_store, kolabconv_free_kmail_part);
 	free_i_task(ipim);
 }
 
-void
+static void
 free_I_note (I_note **ipim)
 {
 	generic_g_list_free (&(*ipim)->common->kolab_attachment_store, kolabconv_free_kmail_part);
@@ -352,15 +374,17 @@ free_I_note (I_note **ipim)
 
 
 #define test_convert_kolab_read_mailfile_read_kolab(PIM_TYPE) \
-void \
+static void \
 test_convert_kolab_read_mailfile_read_kolab_##PIM_TYPE (const test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
+	Kolab_conv_mail *kmail = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	kolabconv_initialize ();\
 	\
-	Kolab_conv_mail *kmail = read_kolab_email_file_tested (args->filename, &stage);\
+	kmail = read_kolab_email_file_tested (args->filename, &stage);\
 	log_xml_part(kmail);\
-	PIM_TYPE *ipim = process_kolab_tested_##PIM_TYPE(kmail, args->validate_op, &stage);\
+	ipim = process_kolab_tested_##PIM_TYPE(kmail, args->validate_op, &stage);\
 	free_##PIM_TYPE(&ipim);\
 	kolabconv_free_kmail(kmail);\
 	\
@@ -372,13 +396,13 @@ test_convert_kolab_read_mailfile_read_kolab(I_event)
 test_convert_kolab_read_mailfile_read_kolab(I_task)
 test_convert_kolab_read_mailfile_read_kolab(I_note)
 
-void
+static void
 free_EContact(EContact *contact)
 {
 	kolabconv_free_econtact(contact);
 }
 
-void
+static void
 free_ECalComponentWithTZ(ECalComponentWithTZ *comp)
 {
 	kolabconv_free_ecalendar(comp);
@@ -386,16 +410,19 @@ free_ECalComponentWithTZ(ECalComponentWithTZ *comp)
 
 
 #define test_convert_evolution_read_vcard_read_evolution(EVO_TYPE, PIM_TYPE) \
-void \
+static void \
 test_convert_evolution_read_vcard_read_evolution_##PIM_TYPE (const test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
-	gchar *vcard = read_text_file_tested(args->filename);\
+	gchar *vcard = NULL;\
+	EVO_TYPE *epim = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	kolabconv_initialize ();\
+	vcard = read_text_file_tested(args->filename);\
 	g_debug("VCard:\n%s", vcard);\
-	EVO_TYPE *epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
+	epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
 	g_free(vcard);\
-	PIM_TYPE *ipim = process_evolution_tested_##PIM_TYPE (epim, args->validate_op, &stage);\
+	ipim = process_evolution_tested_##PIM_TYPE (epim, args->validate_op, &stage);\
 	free_##PIM_TYPE(&ipim);\
 	free_##EVO_TYPE(epim);\
 	/* TODO: log ipim (print_contact(ipim);*/\
@@ -408,18 +435,22 @@ test_convert_evolution_read_vcard_read_evolution(ECalComponentWithTZ, I_task)
 test_convert_evolution_read_vcard_read_evolution(ECalComponentWithTZ, I_note)
 
 #define test_convert_evolution_write_evolution(EVO_TYPE, PIM_TYPE) \
-void \
+static void \
 test_convert_evolution_write_evolution_##PIM_TYPE (const test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
-	gchar *vcard = read_text_file_tested(args->filename);\
-	EVO_TYPE *epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
+	gchar *vcard = NULL;\
+	EVO_TYPE *epim = NULL;\
+	EVO_TYPE *epim2 = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	kolabconv_initialize ();\
+	vcard = read_text_file_tested(args->filename);\
+	epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
 	g_free(vcard);\
-	PIM_TYPE *ipim = process_evolution_tested_##PIM_TYPE (epim, args->validate_op, &stage);\
+	ipim = process_evolution_tested_##PIM_TYPE (epim, args->validate_op, &stage);\
 	free_##EVO_TYPE(epim);\
 	g_message("preconditions ok");\
-	EVO_TYPE *epim2 = create_evolution_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
+	epim2 = create_evolution_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
 	vcard = create_evolution_vcard_tested_##PIM_TYPE(epim2, &stage);\
 	log_debug("%s", vcard);\
 	g_free(vcard);\
@@ -435,21 +466,26 @@ test_convert_evolution_write_evolution(ECalComponentWithTZ, I_task)
 test_convert_evolution_write_evolution(ECalComponentWithTZ, I_note)
 
 #define test_convert_evolution_write_vcard(EVO_TYPE, PIM_TYPE) \
-void \
+static void \
 test_convert_evolution_write_vcard_##PIM_TYPE (const test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
-	gchar *vcard = read_text_file_tested(args->filename);\
-	EVO_TYPE *epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
+	gchar *vcard = NULL;\
+	gchar *vcard_str = NULL;\
+	EVO_TYPE *epim = NULL;\
+	EVO_TYPE *epim2 = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	kolabconv_initialize ();\
+	vcard = read_text_file_tested(args->filename);\
+	epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
 	g_free(vcard);\
 	g_message("preconditions ok");\
-	gchar *vcard_str = create_evolution_vcard_tested_##PIM_TYPE(epim, &stage);\
+	vcard_str = create_evolution_vcard_tested_##PIM_TYPE(epim, &stage);\
 	free_##EVO_TYPE(epim);\
 	g_debug("VCard:\n%s", vcard_str);\
-	EVO_TYPE *epim2 = process_evolution_vcard_tested_##PIM_TYPE(vcard_str, &stage);\
+	epim2 = process_evolution_vcard_tested_##PIM_TYPE(vcard_str, &stage);\
 	g_free(vcard_str);\
-	PIM_TYPE *ipim = process_evolution_tested_##PIM_TYPE (epim2, args->validate_op, &stage);\
+	ipim = process_evolution_tested_##PIM_TYPE (epim2, args->validate_op, &stage);\
 	free_##PIM_TYPE(&ipim);\
 	free_##EVO_TYPE(epim2);\
 	kolabconv_shutdown ();\
@@ -461,18 +497,22 @@ test_convert_evolution_write_vcard(ECalComponentWithTZ, I_task)
 test_convert_evolution_write_vcard(ECalComponentWithTZ, I_note)
 
 #define test_convert_evolution_read_write_kolab(EVO_TYPE, PIM_TYPE) \
-void \
+static void \
 test_convert_evolution_read_write_kolab_##PIM_TYPE (const test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
-	gchar *vcard = read_text_file_tested(args->filename);\
-	EVO_TYPE *epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
+	gchar *vcard = NULL;\
+	EVO_TYPE *epim = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	Kolab_conv_mail *kmail = NULL;\
+	kolabconv_initialize ();\
+	vcard = read_text_file_tested(args->filename);\
+	epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
 	g_free(vcard);\
-	PIM_TYPE *ipim = process_evolution_tested_##PIM_TYPE (epim, args->validate_op, &stage);\
+	ipim = process_evolution_tested_##PIM_TYPE (epim, args->validate_op, &stage);\
 	free_##EVO_TYPE(epim);\
 	g_message("preconditions ok");\
-	Kolab_conv_mail *kmail = create_kolab_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
+	kmail = create_kolab_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
 	log_xml_part(kmail);\
 	ipim = process_kolab_tested_##PIM_TYPE (kmail, args->validate_op, &stage);\
 	free_##PIM_TYPE(&ipim);\
@@ -486,21 +526,26 @@ test_convert_evolution_read_write_kolab(ECalComponentWithTZ, I_task)
 test_convert_evolution_read_write_kolab(ECalComponentWithTZ, I_note)
 
 #define test_convert_evolution_read_write_mailfile(EVO_TYPE, PIM_TYPE) \
-void \
+static void \
 test_convert_evolution_read_write_mailfile_##PIM_TYPE (const test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
-	gchar *vcard = read_text_file_tested(args->filename);\
-	EVO_TYPE *epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
+	gchar *vcard = NULL;\
+	EVO_TYPE *epim = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	Kolab_conv_mail *kmail = NULL;\
+	Kolab_conv_mail *kmail2 = NULL;\
+	kolabconv_initialize ();\
+	vcard = read_text_file_tested(args->filename);\
+	epim = process_evolution_vcard_tested_##PIM_TYPE(vcard, &stage);\
 	g_free(vcard);\
-	PIM_TYPE *ipim = process_evolution_tested_##PIM_TYPE (epim, args->validate_op, &stage);\
+	ipim = process_evolution_tested_##PIM_TYPE (epim, args->validate_op, &stage);\
 	free_##EVO_TYPE(epim);\
-	Kolab_conv_mail *kmail = create_kolab_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
+	kmail = create_kolab_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
 	g_message("preconditions ok");\
 	write_kolab_email_file_tested (tempfile, kmail, &stage);\
 	kolabconv_free_kmail(kmail);\
-	Kolab_conv_mail *kmail2 = read_kolab_email_file_tested (tempfile, &stage);\
+	kmail2 = read_kolab_email_file_tested (tempfile, &stage);\
 	ipim = process_kolab_tested_##PIM_TYPE (kmail2, args->validate_op, &stage);\
 	free_##PIM_TYPE(&ipim);\
 	kolabconv_free_kmail(kmail2);\
@@ -513,17 +558,20 @@ test_convert_evolution_read_write_mailfile(ECalComponentWithTZ, I_task)
 test_convert_evolution_read_write_mailfile(ECalComponentWithTZ, I_note)
 
 #define test_convert_kolab_write_mailfile(EVO_TYPE, PIM_TYPE) \
-void \
+static void \
 test_convert_kolab_write_mailfile_##PIM_TYPE (const test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
-	Kolab_conv_mail *kmail = read_kolab_email_file_tested (args->filename, &stage);\
+	Kolab_conv_mail *kmail = NULL;\
+	Kolab_conv_mail *kmail2 = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	kolabconv_initialize ();\
+	kmail = read_kolab_email_file_tested (args->filename, &stage);\
 	g_message("preconditions ok");\
 	write_kolab_email_file_tested (tempfile, kmail, &stage);\
 	kolabconv_free_kmail(kmail);\
-	Kolab_conv_mail *kmail2 = read_kolab_email_file_tested (tempfile, &stage);\
-	PIM_TYPE *ipim = process_kolab_tested_##PIM_TYPE (kmail2, args->validate_op, &stage);\
+	kmail2 = read_kolab_email_file_tested (tempfile, &stage);\
+	ipim = process_kolab_tested_##PIM_TYPE (kmail2, args->validate_op, &stage);\
 	free_##PIM_TYPE(&ipim);\
 	kolabconv_free_kmail(kmail2);\
 	kolabconv_shutdown ();\
@@ -535,16 +583,19 @@ test_convert_kolab_write_mailfile(ECalComponentWithTZ, I_task)
 test_convert_kolab_write_mailfile(ECalComponentWithTZ, I_note)
 
 #define test_convert_kolab_write_kolab(PIM_TYPE) \
-void \
+static void \
 test_convert_kolab_write_kolab_##PIM_TYPE (const test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
-	Kolab_conv_mail *kmail = read_kolab_email_file_tested (args->filename, &stage);\
-	PIM_TYPE *ipim = process_kolab_tested_##PIM_TYPE (kmail, args->validate_op, &stage);\
+	Kolab_conv_mail *kmail = NULL;\
+	Kolab_conv_mail *kmail2 = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	kolabconv_initialize ();\
+	kmail = read_kolab_email_file_tested (args->filename, &stage);\
+	ipim = process_kolab_tested_##PIM_TYPE (kmail, args->validate_op, &stage);\
 	kolabconv_free_kmail(kmail);\
 	g_message("preconditions ok");\
-	Kolab_conv_mail *kmail2 = create_kolab_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
+	kmail2 = create_kolab_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
 	ipim = process_kolab_tested_##PIM_TYPE (kmail2, args->validate_op, &stage);\
 	free_##PIM_TYPE(&ipim);\
 	kolabconv_free_kmail(kmail2);\
@@ -557,16 +608,19 @@ test_convert_kolab_write_kolab(I_task)
 test_convert_kolab_write_kolab(I_note)
 
 #define test_convert_kolab_read_write_evolution(EVO_TYPE, PIM_TYPE) \
-void \
+static void \
 test_convert_kolab_read_write_evolution_##PIM_TYPE (const test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
-	Kolab_conv_mail *kmail = read_kolab_email_file_tested (args->filename, &stage);\
-	PIM_TYPE *ipim = process_kolab_tested_##PIM_TYPE (kmail, args->validate_op, &stage);\
+	Kolab_conv_mail *kmail = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	EVO_TYPE *epim = NULL;\
+	kolabconv_initialize ();\
+	kmail = read_kolab_email_file_tested (args->filename, &stage);\
+	ipim = process_kolab_tested_##PIM_TYPE (kmail, args->validate_op, &stage);\
 	kolabconv_free_kmail(kmail);\
 	g_message("preconditions ok");\
-	EVO_TYPE *epim = create_evolution_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
+	epim = create_evolution_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
 	ipim = process_evolution_tested_##PIM_TYPE (epim, args->validate_op, &stage);\
 	free_##PIM_TYPE(&ipim);\
 	free_##EVO_TYPE(epim);\
@@ -579,20 +633,25 @@ test_convert_kolab_read_write_evolution(ECalComponentWithTZ, I_task)
 test_convert_kolab_read_write_evolution(ECalComponentWithTZ, I_note)
 
 #define test_convert_kolab_read_write_vcard(EVO_TYPE, PIM_TYPE) \
-void \
+static void \
 test_convert_kolab_read_write_vcard_##PIM_TYPE (test_args_##PIM_TYPE *args)\
 {\
-	kolabconv_initialize ();\
 	gint stage = 0;\
-	Kolab_conv_mail *kmail = read_kolab_email_file_tested (args->filename, &stage);\
-	PIM_TYPE *ipim = process_kolab_tested_##PIM_TYPE (kmail, args->validate_op, &stage);\
+	gchar *vcard_str = NULL;\
+	Kolab_conv_mail *kmail = NULL;\
+	PIM_TYPE *ipim = NULL;\
+	EVO_TYPE *econtact = NULL;\
+	EVO_TYPE *econtact2 = NULL;\
+	kolabconv_initialize ();\
+	kmail = read_kolab_email_file_tested (args->filename, &stage);\
+	ipim = process_kolab_tested_##PIM_TYPE (kmail, args->validate_op, &stage);\
 	kolabconv_free_kmail(kmail);\
-	EVO_TYPE *econtact = create_evolution_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
+	econtact = create_evolution_tested_##PIM_TYPE (ipim, args->validate_op, &stage);\
 	g_message("preconditions ok");\
-	gchar *vcard_str = create_evolution_vcard_tested_##PIM_TYPE(econtact, &stage);\
+	vcard_str = create_evolution_vcard_tested_##PIM_TYPE(econtact, &stage);\
 	free_##EVO_TYPE(econtact);\
 	g_debug("VCard:\n%s", vcard_str);\
-	EVO_TYPE *econtact2 = process_evolution_vcard_tested_##PIM_TYPE(vcard_str, &stage);\
+	econtact2 = process_evolution_vcard_tested_##PIM_TYPE(vcard_str, &stage);\
 	g_free(vcard_str);\
 	ipim = process_evolution_tested_##PIM_TYPE (econtact2, args->validate_op, &stage);\
 	free_##PIM_TYPE(&ipim);\
@@ -611,15 +670,15 @@ test_convert_kolab_read_write_vcard(ECalComponentWithTZ, I_note)
  *
  * @return The current working directory
  */
-gchar*
-get_working_dir ()
+static gchar*
+get_working_dir (void)
 {
-	gchar *path1 = g_new0(gchar, MAXPATHLEN); // This is a buffer for the text
+	gchar *path1 = g_new0(gchar, MAXPATHLEN); /* This is a buffer for the text */
 	getcwd (path1, MAXPATHLEN);
 	return path1;
 }
 
-gchar*
+static gchar*
 create_test_name(gchar *format, gchar *name)
 {
 	gchar *ret = g_strdup_printf (format, name);
@@ -639,9 +698,10 @@ create_test_name(gchar *format, gchar *name)
  *         the informations which are hold in the kolab contact mail
  */
 #define add_tests_kolab(PIM_TYPE) \
-void \
+static void \
 add_tests_kolab_##PIM_TYPE (gchar *filename, void (*validate_op) (const PIM_TYPE*, int)) \
 {\
+	test_args_##PIM_TYPE *args = NULL;\
 	/* create the absolute filename of the contact with the given uid */\
 	gchar *kolab_file_rel = g_strdup_printf("%s%s",\
 			kolab_folder_##PIM_TYPE, filename);\
@@ -650,7 +710,7 @@ add_tests_kolab_##PIM_TYPE (gchar *filename, void (*validate_op) (const PIM_TYPE
 			working_dir, test_resource_folder, kolab_file_rel);\
 	\
 	/* put filename and validating operation in an argument struct to be passed to the test operations */\
-	test_args_##PIM_TYPE *args = g_new0(test_args_##PIM_TYPE, 1);\
+	args = g_new0(test_args_##PIM_TYPE, 1);\
 	args-> filename = kolab_file_name;\
 	args-> validate_op = validate_op;\
 	\
@@ -683,9 +743,10 @@ add_tests_kolab(I_task)
 add_tests_kolab(I_note)
 
 #define add_tests_evolution(PIM_TYPE) \
-void \
+static void \
 add_tests_evolution_##PIM_TYPE (gchar *filename, void (*validate_op) (const PIM_TYPE*, int))\
 {\
+	test_args_##PIM_TYPE *args = NULL;\
 	/* create the absolute filename of the contact with the given uid */\
 	gchar *kolab_file_rel = g_strdup_printf("%s%s",\
 			evolution_folder_##PIM_TYPE, filename);\
@@ -694,7 +755,7 @@ add_tests_evolution_##PIM_TYPE (gchar *filename, void (*validate_op) (const PIM_
 			working_dir, test_resource_folder, kolab_file_rel);\
 	\
 	/* put filename and validating operation in an argument struct to be passed to the test operations */\
-	test_args_##PIM_TYPE *args = g_new0(test_args_##PIM_TYPE, 1);\
+	args = g_new0(test_args_##PIM_TYPE, 1);\
 	args-> filename = kolab_file_name;\
 	args-> validate_op = validate_op;\
 	\
@@ -729,7 +790,7 @@ add_tests_evolution(I_note)
 
 #define add_all_tests(PIM_TYPE) \
 void \
-add_all_tests_##PIM_TYPE()\
+add_all_tests_##PIM_TYPE(void)\
 {\
 	/* add kolab contact tests */\
 	/* get number of contact tests */\
@@ -750,5 +811,3 @@ add_all_tests(I_contact)
 add_all_tests(I_event)
 add_all_tests(I_task)
 add_all_tests(I_note)
-
-
