@@ -52,13 +52,13 @@
 
 #include <glib.h>
 
-#include <camel/camel-stream.h>
 #include <camel/camel-kolab-stream.h>
 
 /* HTTP lib specifics */
 #include <libsoup/soup-gnome.h>
 #include <curl/curl.h>
 
+#include "camel-system-headers.h"
 #include "kolab-util-http.h"
 
 /*----------------------------------------------------------------------------*/
@@ -133,10 +133,10 @@ kolab_util_http_soup_get (const KolabHttpJob *job, GError **error)
 	gssize nbytes = -1;
 	gchar *url_string = NULL;
 
-	g_return_val_if_fail (error == NULL || *error == NULL, -1);
-
 	static gulong kolab_soup_auth_handler_id = 0; /* TODO is 0 an invalid id? */
 
+	g_return_val_if_fail (error == NULL || *error == NULL, -1);
+
 	/* connect the "authenticate" signal handler,
 	 * disconnect a previously connected one.
 	 * TODO: check whether we need to disconnect-connect
